# ------------------------------------------------------------------------------
#  es7s/core
#  (c) 2022-2024 A. Shavykin <0.delameter@gmail.com>
# ------------------------------------------------------------------------------
from __future__ import annotations

import functools
import re
import sys
import tempfile
from functools import partial

import holms.core.cats
import pytermor as pt
from es7s_commons import autogen
from holms.core import Attribute, Options, Char
from holms.core.writer import Row, Column

from es7s.cli._foreign import Pager
from es7s.cli._template import TemplateCommand
from es7s.shared import get_stdout, IoProxy, set_stdout

#      ......    .......  ..    ..  ..........  ..    ..  ...   ..    ......     ##
#     ::....::  ::        ::....::      ::      ::    ::  :: '. ::  ::  ....     ##
#     ::    ::  ':......  ::    ::      ::      ''....''  ::   '::  ''....::     ##
#                                                                                ##
###################################################################################
## This file is a part of my long-term experiment named "Legacy code -- How bad  ##
## can it be?" (tentative assessment: worse than a nightmare) and is maintained  ##
## in a special way, specifically with these rules in mind:                      ##
## +---------------------------------------------------------------------------+ ##
## | 1. Updating / bug fixing should be done by adding new lines.              | ##
## | 2. Changing the existing ones is prohibited unless it's the only possible | ##
## |    way to proceed.                                                        | ##
## +---------------------------------------------------------------------------+ ##
## BTW the 2nd rule is optional; otherwise the order of magnitude of the number  ##
## representing the inverted maintainability score of this crap is unimaginable. ##
###################################################################################
## AN ATTEMPT TO RUN AND/OR COMPREHEND THIS OR OTHER FILE RELATED TO THE PROJECT ##
## MAY BE DANGEROUS FOR YOUR MENTAL HEALTH AND RESULT IN A DISAPPOINTMENT OR/AND ##
## LOSING FAITH IN GLORIOUS FUTURE OF THE 🤩IT* INDUSTRY. PROCEED IF BRAVE ENOUGH ##
###################################################################################


class SgrRenderer:
    pass


class SequenceSGR(pt.SequenceSGR):
    _CLASSIFIER = "️"
    _VIRTUAL = True

    def print(self):
        return self.assemble()

    @property
    def opening_str(self):
        return self.assemble()

    def assemble(self) -> str:
        if len(self._params) == 0:  # NOOP
            return ""
        return (
            self.ESC_CHARACTER
            + ("[")
            + self._assemble_params()
            + (self._interm or "")
            + (self._final or "")
        )

    def __add__(self, other):
        if isinstance(other, SequenceSGR):
            return SequenceSGR(*self.params, *other.params)
        return self.assemble() + (other if other else "")


class Spans:
    pass


class Span:
    pass


class Seqs:
    pass


def pytermor_210_to_18_adapter():
    global seq, fmt, autof
    seq = Seqs
    fmt = Span
    autof = lambda *sq: Span(*sq)

    Seqs.build_c256 = lambda code, bg=False: SequenceSGR.init_color_indexed(code, bg)
    SequenceSGR.print = lambda self: self.assemble()
    fmt.Format = lambda *args, **kwargs: Span.init_explicit(*args, **kwargs)
    for s in dir(pt.cv):
        if s.startswith("__"):
            continue
        if isinstance(c := getattr(pt.cv, s), pt.IColorValue):
            setattr(fmt, s.lower(), c)


Seqs = pt.SeqIndex


def pytermor_258_to_210_adapter():
    global autof, fmt, seq
    seq = Seqs
    SgrRenderer.set_up = lambda _: pt.force_ansi_rendering()
    seq.build_c256 = SequenceSGR.init_color_indexed = lambda code, bg=False: SequenceSGR(
        48 if bg else 38, 5, code
    )
    autofint = lambda *sq, s: pt.enclose(pt.SequenceSGR(*sq), s)
    autof = lambda *sq: (lambda s: autofint(*sq, s=s))
    for sq in Seqs.__dict__:
        if isinstance(SQ := getattr(Seqs, sq), pt.SequenceSGR):
            setattr(Seqs, sq, SequenceSGR(*SQ.params))
    fmt.Format = lambda sq, hard_reset_after: lambda s: s + (
        pt.SeqIndex.RESET.assemble() if hard_reset_after else ""
    )
    for f in fmt.__dict__:
        if not f.startswith("_") and isinstance((ff := getattr(fmt, f)), pt.RenderColor):
            setattr(fmt, f, lambda s: SequenceSGR(ff.to_sgr("bg" in f.lower())).assemble())


@autogen
def i1():
    @autogen
    def i1a():
        BG = pt.make_color_256(234, pt.ColorTarget.BG)
        yield f"{BG}{pt.make_color_256(247)}⡀ 2.2G"
        yield f"{BG}{pt.make_color_256(247)}⣀ 3.8G"
        yield f"{BG}{pt.make_color_256(247)}⣄ 5.4G"
        yield f"{BG}{pt.make_color_256(247)}⣤ 7.7G"
        yield f"{BG}{pt.make_color_256(247)}⣦  11G"
        yield f"{BG}{pt.make_color_256( 94)}⣦  12G"

    @autogen
    def i1b():
        BG = pt.make_color_256(234, pt.ColorTarget.BG)
        yield f"{BG}{pt.make_color_256(136)}⣶  13G"
        yield f"{BG}{pt.make_color_256(172)}⣶  13G"
        yield f"{BG}{pt.make_color_256(208)}⣷  14G"
        yield f"{BG}{pt.make_color_256(202)}⣷  15G"
        yield f"{BG}{pt.make_color_256(160)}⣿  15G"
        yield f"{(mx := pt.Style(bg='red_3')).bg.to_sgr(pt.ColorTarget.BG)}{pt.make_color_256(255)}⣿{BG}" + f"{mx.bg.to_sgr()}  17G"

    while True:
        yield i1a()
        yield i1b()


@autogen
def indicator2_():
    BG = pt.make_color_256(234, pt.ColorTarget.BG) + pt.cv.GREEN.to_sgr()
    yield f"{BG}▉▉▉[37m▏▏▏▏▏▏▏[49m▏ 31%"
    yield f"{BG}▉▉▉▉▉▉[33m▉[37m▏▏▏[49m▏[33m 67%"
    yield f"{BG}▉▉▉▉▉▉[33m▉▉[31m▉▉[49m▏[31m100%"


@autogen
def in3():
    yield "[5;1;97;48;5;160m▕[25;22;39;49m[5;1;97;48;5;160m![25;22;39;49m[5;1;97;48;5;160m▏[25;22;39;49m[5;1;97;48;5;160m [25;22;39;49m[5;1;97;48;5;160m 5%[25;22;39;49m"
    yield "[31m▕[39m[31m![39m[31m▏[39m[1;91m↑[22;39m[31m10%[39m"
    yield "[33m▕[39m[33m▁[39m[33m▏[39m[1;93m [22;39m[33m20%[39m"
    yield "[38;5;239m▕[39m[38;5;243m▂[39m[38;5;239m▏[39m[1;32m↑[22;39m[38;5;247m25%[39m"
    yield "[38;5;239m▕[39m[38;5;243m▂[39m[38;5;239m▏[39m[1;32m [22;39m[38;5;247m30%[39m"
    yield "[38;5;239m▕[39m[38;5;243m▃[39m[38;5;239m▏[39m[1;32m↑[22;39m[38;5;247m50%[39m"
    yield "[38;5;239m▕[39m[38;5;243m▅[39m[38;5;239m▏[39m[1;32m [22;39m[38;5;247m50%[39m"
    yield "[38;5;239m▕[39m[38;5;243m▅[39m[38;5;239m▏[39m[1;32m↑[22;39m[38;5;247m65%[39m"
    yield "[38;5;239m▕[39m[38;5;243m▇[39m[38;5;239m▏[39m[1;32m [22;39m[38;5;247m80%[39m"
    yield "[38;5;239m▕[39m[38;5;243m▇[39m[38;5;239m▏[39m[1;32m↑[22;39m[38;5;247m85%[39m"
    yield "[38;5;239m▕[39m[38;5;243m█[39m[38;5;239m▏[39m[1;32m [22;39m[38;5;247m90%[39m"
    yield "[38;5;239m▕[39m[7;32m✔[27;39m[38;5;239m▏[39m[32mF[39m[38;5;247mULL[39m"


@autogen
def indicator4_():
    yield ""
    yield "[7;31m[49m[27m[39m"
    yield "[7;31m[32;41m[49m[27m[39m"


@autogen
def indic5():
    yield "[▯▯ ▯▯ ▯  ▯]"
    yield "[▯▮▯▮▮▮▮▯▯▮]".replace("▮", "\x1b[32m▮\x1b[39m")
    yield " □[33m■[39m□□[31m□[39m□□[31m■[39m   "
    yield " □□□□□□□□[32m□[39m[32m■[39m "


@autogen
def indicconn():
    yield " 30ms \x1b[38;2;114;160;193m▏\x1b[39m        "
    yield " 86ms \x1b[38;2;2;143;30m▇\x1b[39m        "
    yield " 94ms \x1b[53;38;2;103;108;115m░░\x1b[55;39m\x1b[38;2;1;160;73m▏\x1b[39m      "
    yield "136ms \x1b[53;38;2;103;108;115m░░░\x1b[55;39m\x1b[38;2;238;210;2m▏\x1b[39m     "
    yield "137ms \x1b[53;38;2;103;108;115m░░░\x1b[55;39m\x1b[38;2;255;120;0m▏\x1b[39m     "
    yield "257ms \x1b[53;38;2;103;108;115m░░░░\x1b[55;39m\x1b[38;2;28;169;201m▇▇▇▇\x1b[39m "


@autogen
def indictgthm():
    yield "     " "\x1b[38;2;66;134;194m" "◊◊" "\x1b[39m" " " "\x1b[38;2;66;134;194m" "4286c2" "\x1b[39m" "\x1b[38;5;237m" " " "\x1b[39m"
    yield " 15% " "\x1b[38;2;63;149;235m" "░░" "\x1b[39m" " " "\x1b[38;2;63;149;235m" "3f95eb" "\x1b[39m" "\x1b[38;5;237m" " " "\x1b[39m"
    yield "     " "\x1b[38;2;204;70;70m" "◊◊" "\x1b[39m" " " "\x1b[38;2;204;70;70m" "cc4646" "\x1b[39m" "\x1b[38;5;237m" " " "\x1b[39m"
    yield "     " "\x1b[38;2;202;65;65m" "◊◊" "\x1b[39m" " " "\x1b[38;2;202;65;65m" "ca4141" "\x1b[39m" "\x1b[38;5;237m" " " "\x1b[39m"
    yield " 80% " "\x1b[38;2;255;255;255m" "◊◊" "\x1b[39m" " " "\x1b[38;2;255;255;255m" "ffffff" "\x1b[39m" "\x1b[38;5;237m" " " "\x1b[39m"
    yield "     " "\x1b[38;2;83;98;113m" "◊◊" "\x1b[39m" " " "\x1b[38;2;83;98;113m" "536271" "\x1b[39m" "\x1b[38;5;237m" " " "\x1b[39m"


@autogen
def indicholms():
    cst = holms.core.cats.CategoryStyles()
    R = pt.ansi.SeqIndex.RESET.assemble()
    BG = pt.make_color_256(234, pt.ColorTarget.BG).assemble() + pt.cv.GREEN.to_sgr().assemble()

    def __wrap(s):
        return R + BG + s + R + BG

    from holms.core.view import get_view

    def __render(c):
        o = Options()
        on = Options(_names=True, _rigid=False)
        rw = Row(c, 0, 0)
        r = " "
        r += get_view(Attribute.CAT).render(on, rw, Column(Attribute.CAT, 0, 19)) + " "
        r += get_view(Attribute.CAT).render(o, rw, Column(Attribute.CAT, 0, 2))
        r += get_view(Attribute.CHAR).render(o, rw, Column(Attribute.CHAR))
        r += get_view(Attribute.NUMBER).render(o, rw, Column(Attribute.NUMBER, 0, 4))
        return __wrap(r)

    # fmt: off
    yield __render(Char('\x01'))
    yield __render(Char('\uE0B0'))
    yield __render(Char('\uD800'))
    yield __render(Char('\x30'))
    yield __render(Char('\u2014'))
    yield __render(Char('\x24'))
    # fmt: on


lprot = lambda: " prototype "

pytermor_210_to_18_adapter()
pytermor_258_to_210_adapter()
SgrRenderer.set_up(True)

iop = get_stdout()
tmp_file = None
if iop.io.isatty():
    tmp_file = open(tempfile.mkstemp()[1], "w")
    iop = IoProxy(get_stdout().io_params, tmp_file, sys.stdout)
print = lambda s: iop.echo(s)
set_stdout(iop)


def fmt_group(m, sq):
    g0 = m.groups()[0]
    if g0.startswith(("", "", "")):
        return g0
    if g0:
        return autof(sq)(g0)
    else:
        return autof(sq + seq.CYAN)(m.groups()[1])


def fmt_header(g2, _fmt):
    if not g2:
        return ""
    if g2 and g2.strip() in [
        "PANE",
        "PANES",
        "WINDOW",
        "STATUSBAR",
        "LAYOUT",
        "SESSION",
        "SIGNATURE",
    ]:
        return autof(seq.HI_CYAN)(g2)
    if g2 and g2.strip() in [
        "HEAD",
        "PRFIX",
        "MODIF.",
        "ARROW",
        "BINDING",
        "KEY",
    ]:
        return g2
    return _fmt(g2)


@autogen
def u2b00():
    # fmt: off
    yield "                               " + "║22 Is a part of es7s pack  ║7;38;5;233▐27;39"
    yield "48;5;23522◤◢◤◢◤◢◤◢◤◢◤◢◤◢◤◢◤◢◤◢◤◢◤◢◤◢◤◢◤◢2◤" + "║22 © 2022—2024 A.Shavykin  ║7;38;5;233▐27;39"
    yield "48;5;23522◢2◤GEOMETRY2◢SHAPES22◤◢◤◢◤◢◤◢◤◢◤◢◤2◢" + "║22 <0.delameter@gmail.com> ║7;38;5;233▐27;39"
    yield "48;5;235222◤◢◤◢◤◢◤◢◤◢◤◢◤◢◤◢22◤◢◤◢◤◢◤◢◤◢◤◢◤◢2◤◢◤◢◤◢◤◢◤◢◤◢◤◢◤◢◤◢◤◢◤◢◤◢◤◢ 7;38;5;233▄▟27;39"
    yield " "  "▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄▄  "  ""
    yield "   ■   □   ▢   ▣   ▤   ▥   ▦   ▧    "
    yield "   ▨   ▩   ▪   ▫   ▬   ▭   ▮   ▯    "
    yield "   ▰   ▱   ▲   △   ▴   ▵   ▶   ▷    "
    yield "   ▸   ▹   ►   ▻   ▼   ▽   ▾   ▿    "
    yield "   ◀   ◁   ◂   ◃   ◄   ◅   ◆   ◇    "
    yield "   ◈   ◉   ◊   ○   ◌   ◍   ◎   ●    "
    yield "   ◐   ◑   ◒   ◓   ◔   ◕   ◖   ◗    "
    yield "   ◘   ◙   ◚   ◛   ◜   ◝   ◞   ◟    "
    yield "   ◠   ◡   ◢   ◣   ◤   ◥   ◦   ◧    "
    yield "   ◨   ◩   ◪   ◫   ◬   ◭   ◮   ◯    "
    yield "   ◰   ◱   ◲   ◳   ◴   ◵   ◶   ◷    "
    yield "   ◸   ◹   ◺   ◻   ◼  ◽ "" ◾   ◿    "
    yield " "  "▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀  "  ""
    # fmt: on


@autogen
def pwline():
    yield "                  48;5;23527                                     "
    yield "  POWERLINE EXTRAS    48;5;235;27    U+E0A0…E0A336;48;5;235─U+E0B0…E0D548;5;235    "
    yield "                     48;5;235;2748;5;235;27                                 "


b = lambda s: f"██ {s} ███"


class FBT:
    @autogen
    def __repr__(self):
        yield from ("%s███" % c for c in "█▓▒░")


FB = FBT()
d228 = "[aug22]"
sd239 = "[sep²³]"
sd228 = f"{d228}"


@autogen
def TH():
    t = [
        "twix/twix",
        "twix/twix C",
        "fused/twix",
        "twix/bold C",
        "bold/twix",
        "bold/bold C",
        "bold C",
        "bold C",
    ]
    idx = -1
    while t:
        yield TC((idx := idx + 1), t.pop(0))


def TC(*args):
    return f"[{args[0]}] {args[1]:12s} "


def TN(s):
    return "███" + TC("N", s)


braile_header = "⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣿⣯⣮⢮⠗⠎⠅⡐ ⠁"


def braile_border():
    return ""


B = (lambda: braile_border())()
BR = "███" + B
B3R = B + B + B + BR
Y = ""

LS = "2;36;7 "
L0 = " 0"

dempt = lambda: "[     ]"

# fmt: off
s = f"""
                                                                                                                               GRP  SGN
 ████████████████████████████████████████████████████████   █████████████████████████████████████▓▓███████████████████████████  1   4/3 ██   ██████████████████████████████████████████████████████████
 ██BLOCK█ELEMENTS█████████████████████████ U+2580…259F ██   ██BOX█DRAWINGS████████ U+2500…257F ██▓▓███████████ ╽ █████████████ 2,3  3/2 ██   ██ARROWS████████████████══════════════════════════════════ 
 ████████████████████████████████████████████████████████   █████████████████████████████████████▓▓█████████   ┰   ███████████  4   2/1 ██   █████████ U+2190…21FF ██  ← ↑ → ↓   ↔  ↕  ↖ ↘ ↗ ↙  ⤡ ⤢   │ 
 ████████████████████████████████████████████████████████   ██ ┌┬┐   ┌ ┬ ┐ ███ ─ █ │ ██╴█╶██╷█╵██▓▓███████   ┧ ╁ ┟   █████████ 5,6  3/1 ██   ████████████████████████  ↤ ↥ ↦ ↧      ↨  ⇱ ↸ ⇲ ⯾        │ 
 {b('D')}▁███▂███▃███▄███▅███▆███▇██████{b('U')}▔███▀████   ██ ├┼┤  ├ ┼ ┤  ██████████████████████▓▓█████     ┎ ┯ ┒     ███████  7   4/1 ██   ██SUPPLEMENTAL██████████ ⟵   ⟶    ⟷                      │ 
 █████████⅛███¼███⅜███½███⅝███¾███⅞██████████████⅛███½███   ██ └┴┘ └ ┴ ┘   ███ ━ █ ┃ ██╸█╺██╻█╹██▓▓███    ┏ ┲  ┳  ┱ ┓    █████████████████   ██ARROWS████████████████ ⟻   ⟼                           │ 
 ████████████████████████████████████████████████████████   █████████████████████████████████████▓▓██  ┮ ┍ ┢ ╆ ╈ ╅ ┪ ┑ ┭  ██══════════════   ████████████████████████ ⬱ ⇇ ⇈ ⇉ ⇶ ⇊      ⤿ ⤺  ↺ ⟲ ⥀     │ 
 {b('L')}▏███▎███▍███▌███▋███▊███▉██████{b('R')}▕███▐████   ██ ┏┳┓ ┍┯┑ ┎┰┒ ███ ═ █ ║ ██╾█╼██╿█╽██▓▓██╼┝ ┾ ┠ ┣ ╊ ╉ ┫ ┨ ┽ ┥╾██┵┶2└┘┌┦┞3│┛┾╀│   ████@A ██ U+27F0…27FF ██    ⇄ ⇅ ⇵      ⇆   ⤾ ⤻  ↻ ⟳ ⥁    │ 
 █████████⅛███¼███⅜███½███⅝███¾███⅞██████████████⅛███½███   ██ ┣╋┫ ┝┿┥ ┠╂┨ ██████████████████████▓▓██  ┶ ┗ ┡ ╄ ╇ ╃ ┩ ┙ ┵  ██┭┮└││ ┧┟┘┌4┘└│   ████████████████████████    ⇤ ⤒ ⇥ ⤓    ↹   ⤽ ⤼       ⤳   │ 
 ████████████████████████████████████████████████████████   ██ ┗┻┛ ┕┷┙ ┖┸┚ ███ ╌ █ ╎ ██┄█┈██┊█┆██▓▓███    ┕ ┺  ┻  ┹ ┛    ███└1╿┐ LINE│╁┽┏│   ████@B ██ U+2900…297F ██    ↰ ⬑ ↱ ⬐ ⬎            ⥆ ⥅     │ 
 ██████████████████████████████████████████▟█▙██▘█▝██▞███   █████████████████████████████████████▓▓█████     ┖ ┷ ┚     █████│╾TRANSITION┘│   ████████████████████████  ↵ ↲ ⬏ ↳ ↴ ↯            ⥳ ⥲ ⥴   │ 
 {b('F')}{FB}{FB}{FB}{FB}██████████{b('P')}██████████████   ██ ╔╦╗ ╒╤╕ ╓╥╖ ███ ╍ █ ╏ ██┅█┉██┇█┋██▓▓███████   ┞ ╀ ┦   ███████╼├└╽PRIMER╃╇╄│   ████████████████████████   ⇠ ⇡ ⇢ ⇣             ⥄ ⥃ ⥂     │ 
 █████████1███¾███½███¼████████████████████▜█▛██▖█▗██▚███   ██ ╠╬╣ ╞╪╡ ╟╫╢ ██████████████████████▓▓█████████   ┸   █████████┩┡┤├─┹┺│┌┘╉7╊│   ▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓█ ⤎ ⤌  ⤍ ⤏ ⤑              ⥱ ⥵     │ 
 ████████████████████████████████████████████████████████   ██ ╚╩╝ ╘╧╛ ╙╨╜ ███  ╱╲  █ ╭╰╮╯ █ ╳ ██▓▓███████████ ╿ ███████████┪┢5│┘┱┲6┘│╅╈╆│   █████████████████████▓▓█   ⇐ ⇑ ⇒ ⇓  ⇔   ⇕   ⇖ ⇗ ⇘ ⇙      │ 
                                                  {sd228}   █████████████████████████████████████▓▓███████████████████████████████████████   ████MISCELLANEOUS████▓▓█   ⟸   ⟹    ⟺   ⇳                │ 
                                                            ▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓   ██████SYMBOLS█&██████▓▓█   ⇍   ⇏    ⇎                    │ 
 {                                                      u2b00()}██████████████████████████████████████████████████████████████████████████████   ████████ARROWS███████▓▓█   ⇦ ⇧ ⇨ ⇩      ↞ ↟ ↡ ↠ ⤀ ⤁ ⤐ ⤅  │ 
 {                                                    u2b00()}██{           TH()}██{           TH()}██{           TH()}██{           TH()}██   █████████████████████▓▓█   ⇽   ⇾        ↢ ⤉ ⤈ ↣ ⤔ ⤕ ⥇ ↮  │ 
 {                                                    u2b00()}██ ╔══════╦══════╗ ██ ╔══════╤══════╗ ██ ╔═════════════╗ ██ ╔══════╦══════╗ ██   ████ U+2B00…21FF ████▓▓█   ⇚ ⤊ ⇛ ⤋       ⇞ ⇟   ⤟ ⤝ ⤞ ⤠   │ 
 {                                                    u2b00()}██ ║ HEAD ║ HEAD ║ ██ ║ HEAD │ HEAD ║ ██ ║ HEAD ┃ HEAD ║ ██ ║ HEAD ║ HEAD ║ ██   █████████████████████▓▓█     ⟰  ⟱    ⬰ ⥉ ⥈   ⤖ ⤗ ⤘       │ 
 █████████████████████{                             u2b00()}  ██ ╠══════╩══════╣ ██ ╠══════╪══════╣ ██ ║━━━━━━┻━━━━━━║ ██ ╚══════╩══════╝ ██   ██┌───────────────┐██▓▓█   ⤆  ⤇                          │ 
 ██ U+25A0 ███████████{                             u2b00()}  ██ ║ CELL │ CELL ║ ██ ║ CELL │ CELL ║ ██ ║ CELL │ CELL ║ ██ ┃ CELL │ CELL ┃ ██   ██│  ⬒ ⬓ ⬔ ⬕ ⬚ ⬞  │██▓▓█   ⟽  ⟾        ⤧⤨⤩⤪⤫⤬  ⤲⤱⤭⤮⤯⤰    │ 
 ████████████ …25AF ██{                             u2b00()}  ██ ║──────┼──────║ ██ ╟──────┼──────╢ ██ ║──────┼──────║ ██ ┠──────┼──────┨ ██   ██│   ⬖ ⬗ ⬘ ⬙ ⬝   │██▓▓█   ⤂  ⤃    ⤄                     │ 
 ██ U+25B0 ███████████{                             u2b00()}  ██ ║ CELL │ CELL ║ ██ ║ CELL │ CELL ║ ██ ║ CELL │ CELL ║ ██ ┃ CELL │ CELL ┃ ██   ██│    ⬟ ⬠ ⭓ ⭔    │██▓▓█   ⇪⇫⇬⇭⇮⇯ ⇰  ⬄   ⬁ ⬀ ⬂ ⬃    ⥰ ⥺  │ 
 ████████████ …25BF ██{                             u2b00()}  ██ ╚═════════════╝ ██ ╚══════╧══════╝ ██ ╚═════════════╝ ██ ┗━━━━━━┷━━━━━━┛ ██   ██│     ⬡ ⬢ ⬣     │██▓▓█   ⬅ ⬆ ⮕ ⬇    ⬌ ⬍ ⬉ ⬈ ⬊ ⬋   ⥻ ⥹  │ 
 ██ U+25C0 ███████████{                             u2b00()}  ██████████████████████████████████████████████████████████████████████████████   ██│      ⯊ ⯋      │██▓▓█   ↩ ↶ ↪ ↷        ⤣ ⤤ ⤥ ⤦  ⥼ ⥾ ⥽ │ 
 ████████████ …25CF ██{                             u2b00()}  ██{           TH()}██{           TH()}██{           TH()}██{           TH()}██   ██│     ⬥ ⬦ ⬧     │██▓▓█  ⤶ ⤵ ⤷ ⤴          ⤹⤸      ⥶ ⥷ ⥸ │ 
 ██ U+25D0 ███████████{                             u2b00()}  ██ ┏━━━━━━┳━━━━━━┓ ██ ┏━━━━━━┳━━━━━━┓ ██ ┏━━━━━━┳━━━━━━┓ ██ ┏━━━━━━┳━━━━━━┓ ██   ██│    ⬨ ⬩ ⬪ ⬫    │██▓▓█    ⥒ ⥖   ⥘ ⥔     ⥓ ⥗     ⥙ ⥕    │ 
 ████████████ …25DF ██{                             u2b00()}  ██ ┃ HEAD ┃ HEAD ┃ ██ ┃ HEAD ┃ HEAD ┃ ██ ┃ HEAD ┃ HEAD ┃ ██ ┃ HEAD ┃ HEAD ┃ ██   ██│   ⭘ ⬬ ⬭ ⬮ ⬯   │██▓▓█ ⥚ ⥢ ⥞   ⥠ ⥣ ⥜     ⥟ ⥤ ⥛   ⥡ ⥥ ⥝ │ 
 ██ U+25E0 ███████████{                             u2b00()}  ██ ┗━━━━━━┻━━━━━━┛ ██ ┣━━━━━━╇━━━━━━┫ ██ ┡━━━━━━╇━━━━━━┩ ██ ┗━━━━━━┻━━━━━━┛ ██   ██│  ⭑ ⭒ ⯨ ⯩ ⯪ ⯫  │██▓▓█ ⥫ ⥪ ⥊ ⥑ ⥍ ⥮ ⥯ ⥌⥏   ⥋ ⥬ ⥭ ⥎      │ 
 ████████████ …25EF ██{                             u2b00()}  ██ ║ CELL │ CELL ║ ██ ┃ CELL │ CELL ┃ ██ │ CELL │ CELL │ ██ │ CELL │ CELL │ ██   ██└───────────────┘██▓▓█        ⥩ ⥦ ⥨ ⥧ ⥐                │ 
 ██ U+25F0 ███████████{                             u2b00()}  ██ ╟──────┼──────╢ ██ ┠──────┼──────┨ ██ ├──────┼──────┤ ██ │──────│──────│ ██   █████████████████████▓▓███████████████████████████████████ 
 ████████████ …25FF ██{                             u2b00()}  ██ ║ CELL │ CELL ║ ██ ┃ CELL │ CELL ┃ ██ │ CELL │ CELL │ ██ │ CELL │ CELL │ ██                                                      [     ] 
 █████████████████████{                             u2b00()}  ██ ╚══════╧══════╝ ██ ┗━━━━━━┷━━━━━━┛ ██ └──────┴──────┘ ██ └─────────────┘ ██ 
                                 $ah mothefucker ^{ d228}   ██████████████████████████████████████████████████████████████████████████████   ██████████████████████████████████████████████████████████
                                                            ████████████████████████████████████████{TN("[header][/border] [attrs]...")}██   ██MISCELLANEOUS█TECHNICAL██████████████████ U+2300…23FF ██ 
 {                                                  pwline()} ██████████████████████████████████████████████████████████████████████████████   ██████████████████████████████████████████████████████████ 
 {                                                  pwline()}                                                                        {sd228}   █▓▓█▓▓█▓▓█▓▓█▓▓█▓▓█▓▓▓▓████░░░░░░░░░░░░░░░░░░░░░░░░░░░░░██ 
 {                                                  pwline()}                                                                                  █()░❨❩░❪❫░⦅⦆░❲❳░⸨⸩░﹙﹚████░░⌜░⌝░⌌░⌍░░░░░⎮░⎪░⎥░⎢░⎟░⎜░░░░██ 
 █████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████   ░░░░░░░░░░░░░░░░░░░░░░░████░░⌞░⌟░⌎░⌏░░░░░░░░░░░░░░░░░░░░██ 
 ██   ██   ██   █   ██   █   ██   █   █   █   ██      ██    ██    █   ██   ██   █   ██   ██   ██   █▓▓▓██▓▓▓███▓▓▓▓███▓▓▓▓████░░░░░░░░░░░⎸░⏐░⎹░░⎺░⎻░⎼░⎽░⎯░░██ 
 █████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████████   █⁽³⁾░░₍₄₎░░█（）█░█｟｠████░░░░░░░░░░░░░░░░░░░░░░░░░░░░░██ 
                                                                                                                                   {sd228}   ⌇░░░░░░░░░░░░░░░░░░░░░░█████████████10███████⎯⎯███████████ 
                                                                                                                                             ████████████████████████████████████⎲██████³⎷27███████⏞███ 
 {  ''}█████████████{                                                    braile_header} █DINGBATS/CIRCLE█                  {LS}⋅·⦁∙•⏺●⬤◌∘◦⚬⭘○◉◎⊙⊚⦿{L0}   ███⎛█⏜█⏜█⏜█⎞█⎛█  ᪾᪽᪻᪼██over█⎞███⎰0⎱█⌈1⌉█⎳████████████████123██ 
 {  ''}██BRAILLE██████████████████████████████████████████████████████████████████████  ████████████████████████████████████████████████████████   ███⎜▓A▓B▓C▓⎟█⎜▓▓▓▓▓▓▓▓▓▓⎟███⎱0⎰█⌊2⌋█x=1██⎧ x=2; ⎫██⎯██⏟███ 
 {  ''}████PATTERNS███@0 █@1 █@2 █@3 █@4 █@5 █@6 █@7 █@8 █@9 █@A █@B █@C █@D █@E █@F █  █ U+22C5 █│ ⋅ │█Sm█@DOT OPERATOR ███████████████████████   ███⎝▓⏝▓⏝▓⏝▓⎠█⎝█ ᪾  ᪽  ᪻  ᪼ █⎠████████████████⎪ y<5; ⎪██1██████                                                       # NamedSequences-15.0.0.txt    https://www.unicode.org/Public/15.0.0/ucd/NamedSequences.txt
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+00B7 █│ · │█Po█@MIDDLE DOT █████████████████████████   ████████████████████████████3⌠███⎡5 7⎤███⎨ i>9; ⎬██⎶██⏠███                                                       # Name of Sequence; Code Point Sequence for USI
 {B}█ U+2800…280F █ ⠀ █ ⠁ █ ⠂ █ ⠃ █ ⠄ █ ⠅ █ ⠆ █ ⠇ █ ⠈ █ ⠉ █ ⠊ █ ⠋ █ ⠌ █ ⠍ █ ⠎ █ ⠏ █{B}  █ U+2981 █│ ⦁ │█Sm█@Z NOTATION SPOT ████████████████████   ██⌷█⎕█⌸█⍯█⍰█⍠█⍁█⍂█⍃█⍄█⍇█⍈████⎮███⎢6 7⎥███⎪ t=2; ⎪██2██12██                                                       # EXAMPLE NAME     ; 1000 1001 1002
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+2219 █│ ∙ │█Sm█@BULLET OPERATOR ████████████████████   ███⌺█⌻█⌼█⍞█⌹█⍍█⍔█⍓█⍌█⍐█⍗████0⌡███⎣7 7⎦███⎩ a=0; ⎭██⎵██⏡███                                                       
 █{B} U+2810…281F █ ⠐ █ ⠑ █ ⠒ █ ⠓ █ ⠔ █ ⠕ █ ⠖ █ ⠗ █ ⠘ █ ⠙ █ ⠚ █ ⠛ █ ⠜ █ ⠝ █ ⠞ █ ⠟ {B}█  █ U+2022 █│ • │█Po█@BULLET █████████████████████████████   ██████████████████████████████████████████████████████████                                                       KEYCAP NUMBER SIGN ; 0023 FE0F 20E3 ; #️ ; # ️ ⃣
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+23FA █│ ⏺ │█So█@BLACK CIRCLE FOR RECORD ████████████                                                      [jul²³]                                                       KEYCAP ASTERISK    ; 002A FE0F 20E3 ; *️⃣ ; * ️ ⃣
 {B}█ U+2820…282F █ ⠠ █ ⠡ █ ⠢ █ ⠣ █ ⠤ █ ⠥ █ ⠦ █ ⠧ █ ⠨ █ ⠩ █ ⠪ █ ⠫ █ ⠬ █ ⠭ █ ⠮ █ ⠯ █{B}  █ U+25CF █│ ● │█So█@BLACK CIRCLE ███████████████████████                                                                                                                    KEYCAP DIGIT ZERO  ; 0030 FE0F 20E3 ; 0️⃣ ; 0 ️ ⃣
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+2B24 █│ ⬤ │█So█@BLACK LARGE CIRCLE █████████████████   ███████████████INDICATORS████████████████         [↓aug²³]                                                       KEYCAP DIGIT ONE   ; 0031 FE0F 20E3 ; 1️⃣ ; 1 ️ ⃣
 █{B} U+2830…283F █ ⠰ █ ⠱ █ ⠲ █ ⠳ █ ⠴ █ ⠵ █ ⠶ █ ⠷ █ ⠸ █ ⠹ █ ⠺ █ ⠻ █ ⠼ █ ⠽ █ ⠾ █ ⠿ {B}█  █ U+25CC █│ ◌ │█So█@DOTTED CIRCLE ██████████████████████   ▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓█████████████████                                                       KEYCAP DIGIT TWO   ; 0032 FE0F 20E3 ; 2️⃣ ; 2 ️ ⃣
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+2218 █│ ∘ │█Sm█@RING OPERATOR ██████████████████████   ███████████████████████████████████████████{i1()}█{i1()}██                                                       KEYCAP DIGIT THREE ; 0033 FE0F 20E3 ; 3️⃣ ; 3 ️ ⃣
 {B}█ U+2840…284F █ ⡀ █ ⡁ █ ⡂ █ ⡃ █ ⡄ █ ⡅ █ ⡆ █ ⡇ █ ⡈ █ ⡉ █ ⡊ █ ⡋ █ ⡌ █ ⡍ █ ⡎ █ ⡏ █{B}  █ U+25E6 █│ ◦ │█So█@WHITE BULLET ███████████████████████   ██{indicator2_()}█████{ indicator4_()}█████{i1()}█{i1()}██                                                       KEYCAP DIGIT FOUR  ; 0034 FE0F 20E3 ; 4️⃣ ; 4 ️ ⃣
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+26AC █│ ⚬ │█So█@MEDIUM SMALL WHITE CIRCLE ██████████   ██▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓█████▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓█████{i1()}█{i1()}██                                                       KEYCAP DIGIT FIVE  ; 0035 FE0F 20E3 ; 5️⃣ ; 5 ️ ⃣
 █{B} U+2850…285F █ ⡐ █ ⡑ █ ⡒ █ ⡓ █ ⡔ █ ⡕ █ ⡖ █ ⡗ █ ⡘ █ ⡙ █ ⡚ █ ⡛ █ ⡜ █ ⡝ █ ⡞ █ ⡟ {B}█  █ U+2B58 █│ ⭘ │█So█@HEAVY CIRCLE ███████████████████████   ██{indicator2_()}█████{ indicator4_()}█████{i1()}█{i1()}██                                                       KEYCAP DIGIT SIX   ; 0036 FE0F 20E3 ; 6️⃣ ; 6 ️ ⃣
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+25CB █│ ○ │█So█@WHITE CIRCLE ███████████████████████   ██▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓█████▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓█████{i1()}█{i1()}██                                                       KEYCAP DIGIT SEVEN ; 0037 FE0F 20E3 ; 7️⃣ ; 7 ️ ⃣
 {B}█ U+2860…286F █ ⡠ █ ⡡ █ ⡢ █ ⡣ █ ⡤ █ ⡥ █ ⡦ █ ⡧ █ ⡨ █ ⡩ █ ⡪ █ ⡫ █ ⡬ █ ⡭ █ ⡮ █ ⡯ █{B}  █ U+25C9 █│ ◉ │█So█@FISHEYE ████████████████████████████   ██{indicator2_()}█████{ indicator4_()}█████{i1()}█{i1()}██                                                       KEYCAP DIGIT EIGHT ; 0038 FE0F 20E3 ; 8️⃣ ; 8 ️ ⃣
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+25CE █│ ◎ │█So█@BULLSEYE ███████████████████████████   ██▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓█████▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓█████▓▓▓▓▓▓█▓▓▓▓▓▓██                                                       KEYCAP DIGIT NINE  ; 0039 FE0F 20E3 ; 9️⃣ ; 9 ️ ⃣
 █{B} U+2870…287F █ ⡰ █ ⡱ █ ⡲ █ ⡳ █ ⡴ █ ⡵ █ ⡶ █ ⡷ █ ⡸ █ ⡹ █ ⡺ █ ⡻ █ ⡼ █ ⡽ █ ⡾ █ ⡿ {B}█  █ U+2299 █│ ⊙ │█Sm█@CIRCLED DOT OPERATOR ███████████████   ███████{  lprot()}██████████{  lprot()}███████{  lprot()}█                                                                                                     
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+229A █│ ⊚ │█Sm█@CIRCLED RING OPERATOR ██████████████   ██████████████████████████████████████████████████████████                                                                                                     
 {B}█ U+2880…288F █ ⢀ █ ⢁ █ ⢂ █ ⢃ █ ⢄ █ ⢅ █ ⢆ █ ⢇ █ ⢈ █ ⢉ █ ⢊ █ ⢋ █ ⢌ █ ⢍ █ ⢎ █ ⢏ █{B}  █ U+29BF █│ ⦿ │█Sm█@CIRCLED BULLET██████████████████████   ██{  indicconn()}█████{in3()}██{in3()}█████{  indic5()}███ 
 {  ''}███████████████████████████████████████████████████████████████████████████████  ████████████████████████████████████████████████████████   ██{  indicconn()}█████{in3()}██{in3()}█████{  indic5()}███ 
 █{B} U+2890…289F █ ⢐ █ ⢑ █ ⢒ █ ⢓ █ ⢔ █ ⢕ █ ⢖ █ ⢗ █ ⢘ █ ⢙ █ ⢚ █ ⢛ █ ⢜ █ ⢝ █ ⢞ █ ⢟ {B}█                                                   {  dempt()}   ██{  indicconn()}█████{in3()}██{in3()}█████▓▓▓▓▓▓▓▓▓▓▓▓███                                    ABCDEFGHIJKLMNOPQRSTUVWXYZ 0123456789⁴₃
 {  ''}███████████████████████████████████████████████████████████████████████████████                                                               ██{  indicconn()}█████{in3()}██{in3()}██████|[transmorph]|                                    abcdefghijklmnopqrstuvwxyz ΑΒΓΔΩαβγδω
 {B}█ U+28A0…28AF █ ⢠ █ ⢡ █ ⢢ █ ⢣ █ ⢤ █ ⢥ █ ⢦ █ ⢧ █ ⢨ █ ⢩ █ ⢪ █ ⢫ █ ⢬ █ ⢭ █ ⢮ █ ⢯ █{B}  █DINGBATS/TRIANGLE█                   {LS}▲△▴▵▶▷▸▹▼▽▾▿◀◁◂◃{L0}   ██{  indicconn()}█████{in3()}██{in3()}█████{  indic5()}███                                    –—‘“”„ µÀÆÖÞßéöÿἠḂӥ œŠŸžɐﬁ БДЁЖЗбдёжз                                              v
 {  ''}███████████████████████████████████████████████████████████████████████████████  ████████████████████████████████████████████████████████   ██{  indicconn()}█████{in3()}██{in3()}█████{  indic5()}███                                    €™©†•…‰ː ┐┼╔╘░►☺♀ ∀∂∈∧∪≡∞ℝ ↑↗↨↻⇣ �⑀⍎Աაא           
 █{B} U+28B0…28BF █ ⢰ █ ⢱ █ ⢲ █ ⢳ █ ⢴ █ ⢵ █ ⢶ █ ⢷ █ ⢸ █ ⢹ █ ⢺ █ ⢻ █ ⢼ █ ⢽ █ ⢾ █ ⢿ {B}█  █ U+25B2 █│ ▲ │█So█@BLACK UP-POINTING TRIANGLE █████████   ██▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓█████▓▓▓▓▓▓▓██▓▓▓▓▓▓▓█████▓▓▓▓▓▓▓▓▓▓▓▓███                                                                                      
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+25B3 █│ △ │█So█@WHITE UP-POINTING TRIANGLE █████████   ██|[7s con, holms]|█████|[es7s mon bat]|███████|[fudrapp]|                ╔══╦══╗  ┌──┬──┐  ╭──┬──╮  ╭──┬──╮  ┏━━┳━━┓  ┎┒┏┑   ╷  ╻ ┏┯┓ ┌┰┐    █ ╱╲╱╲╳╳╳
 {B}█ U+28C0…28CF █ ⣀ █ ⣁ █ ⣂ █ ⣃ █ ⣄ █ ⣅ █ ⣆ █ ⣇ █ ⣈ █ ⣉ █ ⣊ █ ⣋ █ ⣌ █ ⣍ █ ⣎ █ ⣏ █{B}  █ U+25B4 █│ ▴ │█So█@BLACK UP-POINTING SMALL TRIANGLE ███   ██████████████████████████████████████████████████████████                ║┌─╨─┐║  │╔═╧═╗│  │╒═╪═╕│  │╓─╁─╖│  ┃┌─╂─┐┃  ┗╃╄┙  ╶┼╴╺╋╸┠┼┨ ┝╋┥    ▉ ╲╱╲╱╳╳╳                                                          
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+25B5 █│ ▵ │█So█@WHITE UP-POINTING SMALL TRIANGLE ███   ██{ indictgthm()}█████{                   indicholms()}███                ║│╲ ╱│║  │║   ║│  ││ │ ││  │║ ┃ ║│  ┃│ ╿ │┃  ┍╅╆┓   ╵  ╹ ┗┷┛ └┸┘    ▊ ╱╲╱╲╳╳╳
 █{B} U+28D0…28DF █ ⣐ █ ⣑ █ ⣒ █ ⣓ █ ⣔ █ ⣕ █ ⣖ █ ⣗ █ ⣘ █ ⣙ █ ⣚ █ ⣛ █ ⣜ █ ⣝ █ ⣞ █ ⣟ {B}█  █ U+25B6 █│ ▶ │█So█@BLACK RIGHT-POINTING TRIANGLE ██████   ██{ indictgthm()}█████{                   indicholms()}███                ╠╡ ╳ ╞╣  ├╢   ╟┤  ├┼─┼─┼┤  ├╫─╂─╫┤  ┣┿╾┼╼┿┫  ┕┛┖┚     ┌┄┄┐ ╎ ┏┅┅┓ ┋ ▋ ╲╱╲╱╳╳╳
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+25B7 █│ ▷ │█Sm█@WHITE RIGHT-POINTING TRIANGLE ██████   ██{ indictgthm()}█████{                   indicholms()}███                ║│╱ ╲│║  │║   ║│  ││ │ ││  │║ ┃ ║│  ┃│ ╽ │┃  ░░▒▒▓▓██ ┊  ┆ ╎ ╏  ┇ ┋ ▌
 {B}█ U+28E0…28EF █ ⣠ █ ⣡ █ ⣢ █ ⣣ █ ⣤ █ ⣥ █ ⣦ █ ⣧ █ ⣨ █ ⣩ █ ⣪ █ ⣫ █ ⣬ █ ⣭ █ ⣮ █ ⣯ █{B}  █ U+25B8 █│ ▸ │█So█@BLACK RIGHT-POINTING SMALL TRIANGLE█   ██{ indictgthm()}█████{                   indicholms()}███                ║└─╥─┘║  │╚═╤═╝│  │╘═╪═╛│  │╙─╀─╜│  ┃└─╂─┘┃  ░░▒▒▓▓██ ┊  ┆ ╎ ╏  ┇ ┋ ▍
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+25B9 █│ ▹ │█So█@WHITE RIGHT-POINTING SMALL TRIANGLE█   ██{ indictgthm()}█████{                   indicholms()}███                ╚══╩══╝  └──┴──┘  ╰──┴──╯  ╰──┴──╯  ┗━━┻━━┛  ▗▄▖▛▀▜   └╌╌┘ ╎ ┗╍╍┛ ┋ ▎
 █{B} U+28F0…28FF █ ⣰ █ ⣱ █ ⣲ █ ⣳ █ ⣴ █ ⣵ █ ⣶ █ ⣷ █ ⣸ █ ⣹ █ ⣺ █ ⣻ █ ⣼ █ ⣽ █ ⣾ █ ⣿ {B}█  █ U+25BC █│ ▼ │█So█@BLACK DOWN-POINTING TRIANGLE ███████   ██{ indictgthm()}█████{                   indicholms()}███                                                             ▝▀▘▙▄▟                 ▏▁▂▃▄▅▆▇█
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+25BD █│ ▽ │█So█@WHITE DOWN-POINTING TRIANGLE ███████   ██▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓█████▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓███       
 {Y}⣶⣿⠿⠛⣉⣤⣶⣿⠿⠛⣉⣤⣶⣿⠿⠛⣉⣤⣶⣿⠿⠛⣉⣤⣶⣿⠿⠛⣉⣤⣶⣿⠿⠛⣉⣤⣶⣿⠿⠛⣉⣤⣶⣿⠿⠛⣉⣤⣶⣿⠿⠛⣉⣤⣶⣿⠿⠛⣉⣤⣶⣿⠿[aug22↑][↓may23] {Y} █ U+25BE █│ ▾ │█So█@BLACK DOWN-POINTING SMALL TRIANGLE █   ████|[7s print tg]|██████████████████████████████|[holms]|  
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+25BF █│ ▿ │█So█@WHITE DOWN-POINTING SMALL TRIANGLE █   ██████████████████████████████████████████████████████████                             ╔══════════════════╦═ 
 {  ''}█[0]█████████████████[1]███████████████████████████████[7]█████████████████[8]█  █ U+25C0 █│ ◀ │█So█@BLACK LEFT-POINTING TRIANGLE ███████   ▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓                             ║ Active operation ║                 
 █ ⠀ {BR} ⠁ █ ⠂ █ ⠄ █ ⠈ █ ⠐ █ ⠠ █ ⡀ █ ⢀ {B3R} ⡿ █ ⢿ █ ⣟ █ ⣯ █ ⣷ █ ⣻ █ ⣽ █ ⣾ {B}███ ⣿ █  █ U+25C1 █│ ◁ │█Sm█@WHITE LEFT-POINTING TRIANGLE ███████                                                      {sd239}                             ║━━━━━━┓╮▁╮┓  mode ║                 
 {  ''}████[2]███████████[3]█████████████████[4]█████████████████[5]███████████[6]████  █ U+25C2 █│ ◂ │█So█@BLACK LEFT-POINTING SMALL TRIANGLE █                                                                                              ║ Data ┗╰▔╰┗━━━━━━━║─                
 {B}█ ⠃ ⠅ ⠆ ⠉ █ ⠇ ⠋ ⠍ ⠎ ⠓ ⠕ ⠖ ⠙ █ ⠏ ⠗ ⠛ ⠝ ⠞ ⠧ ⠫ ⠭ ⠮ ⠳ █ ⠟ ⠯ ⠷ ⠻ ⠽ ⠾ ⡏ ⡗ █ ⠿ ⡟ ⡯ ⡷ {B}█  █ U+25C3 █│ ◃ │█So█@WHITE LEFT-POINTING SMALL TRIANGLE █                                                                                              ║━━━━━━┓╮╮▁╮╮ mode ║                 
 █{B} ⠊ ⠌ ⠑ ⠒ █ ⠚ ⠜ ⠣ ⠥ ⠦ ⠩ ⠪ ⠬ █ ⠵ ⠶ ⠹ ⠺ ⠼ ⡇ ⡋ ⡍ ⡎ ⡓ █ ⡛ ⡝ ⡞ ⡧ ⡫ ⡭ ⡮ ⡳ █ ⡻ ⡽ ⡾ ⢟ {B}█  ████████████████████████████████████████████████████████                                                                                              ║ Data ┗╯╯▔╯╯━━━━━━║                 
 {B}█ ⠔ ⠘ ⠡ ⠢ █ ⠱ ⠲ ⠴ ⠸ ⡃ ⡅ ⡆ ⡉ █ ⡕ ⡖ ⡙ ⡚ ⡜ ⡣ ⡥ ⡦ ⡩ ⡪ █ ⡵ ⡶ ⡹ ⡺ ⡼ ⢏ ⢗ ⢛ █ ⢯ ⢷ ⢻ ⢽ {B}█                                                   [     ]                                                                                            ║━━━━━━┏╭╭╭▁┓ mode ║                                                                                                    
 █{B} ⠤ ⠨ ⠰ ⡁ █ ⡊ ⡌ ⡑ ⡒ ⡔ ⡘ ⡡ ⡢ █ ⡬ ⡱ ⡲ ⡴ ⡸ ⢇ ⢋ ⢍ ⢎ ⢓ █ ⢝ ⢞ ⢧ ⢫ ⢭ ⢮ ⢳ ⢵ █ ⢾ ⣏ ⣗ ⣛ {B}█                                                                                                                                                          ║ Data ┗╰╰╰▔┗━━━━━━║                       █ U+2600…27FF █                                                           
 {B}█ ⡂ ⡄ ⡈ ⡐ █ ⡤ ⡨ ⡰ ⢃ ⢅ ⢆ ⢉ ⢊ █ ⢕ ⢖ ⢙ ⢚ ⢜ ⢣ ⢥ ⢦ ⢩ ⢪ █ ⢶ ⢹ ⢺ ⢼ ⣇ ⣋ ⣍ ⣎ █ ⣝ ⣞ ⣧ ⣫ {B}█  █QUOTATION█&█COMMA█MARKS█      {LS}"'`´‹›«»‘’“”‚‛„‟⹂❛❜❝❞❟❠{L0}                                                                                              ║ Active operation ║                                                                                                             
 █{B} ⡠ ⢁ ⢂ ⢄ █ ⢌ ⢑ ⢒ ⢔ ⢘ ⢡ ⢢ ⢤ █ ⢬ ⢱ ⢲ ⢴ ⢸ ⣃ ⣅ ⣆ ⣉ ⣊ █ ⣓ ⣕ ⣖ ⣙ ⣚ ⣜ ⣣ ⣥ █ ⣭ ⣮ ⣳ ⣵ {B}█  ████████████████████████████████████████████████████████                                                                                                    ║━━━━━━┏▁┓▁▁▁┏━┓▁┏ m                       ❬ ❭ ❮ ❯ ❰ ❱ ⟨ ⟩ ⟪ ⟫                                                       
 {B}█ ⢈ ⢐ ⢠ ⣀ █ ⢨ ⢰ ⣁ ⣂ ⣄ ⣈ ⣐ ⣠ █ ⣌ ⣑ ⣒ ⣔ ⣘ ⣡ ⣢ ⣤ ⣨ ⣰ █ ⣦ ⣩ ⣪ ⣬ ⣱ ⣲ ⣴ ⣸ █ ⣶ ⣹ ⣺ ⣼ {B}█  █ U+0022 █│ " │█Po█@QUOTATION MARK █████████████████████                                                                                                    ║ Data ┗▔┛▔┗━┛▔┗━┛━━                    ✩ ✪ ✫ ✬ ✭ ✮ ✯ ✯                                                              
 {  ''}███████████████████████████████████████████████████████████████████████████████  █ U+0027 █│ ' │█Po█@APOSTROPHE █████████████████████████                                                                                                    ║   flow direction ║                      ✅ ✓ ✔ ☐ ☑ ☑ ☓                                                               
 █»42s¹c₃f¾█»31s¹c₃f⅔█»41s¹c₂f¼█»41s¹c₂f¾█»41s¹c₂f½█»21s¹c₁f½█»42s²c₂f½█»62s¹c₆f⅔███████  █ U+0060 █│ ` │█Sk█@GRAVE ACCENT ███████████████████████ ···················································             ║══════════════════║                               ✕ ✕ ✗ ✘ ❌ ❌ ❖                                                                 
 █▅▅▅▅▅▅▅▅│▅▅▅▅▅▅▅▅│▅▅▅▅▅▅▅▅│▅▅▅▅▅▅▅▅│▅▅▅▅▅▅▅▅│▅▅▅▅▅▅▅▅│▅▅▅▅▅▅▅▅│▅▅▅▅▅▅▅▅│▅▅▅▅▅█  █ U+00B4 █│ ´ │█Sk█@ACUTE ACCENT ███████████████████████ ···················································             ║──────╮╮╮╮╮╮ mode ║                                     ☠ ☢ ☣ ♻ ♼ ♽ ♾                U+0301  ́ COMBINING ACUTE ACCENT              
 █«⡾»⢟⣫⣵⡾⢟⣫⣵│«⠰»⣫⢞⡵⣫⢞⡵⣫│«⠐»⢁⠔⢁⠔⢁⠔⢁│«⢨»⡾⣫⡾⣫⡾⣫⡾│«⢠»⠞⣡⠞⣡⠞⣡⠞│«⠨»⡪⡪⡪⡪⡪⡪⡪│«⠛»⣤⠛⣤⠛⣤⠛⣤│«⠿»⠛⣉⣤⣶⣿⠿⠛│     █  ████████████████████████████████████████████████████████ ·················································             ║ Data ╰╰╰╰╰╰──────║                                              ⚙ ⚛ ⚠                                                                           
 █⡾⢟⣫⣵⡾⢟⣫⣵│⢞⡵⣫⢞⡵⣫⢞⡵│⠔⢁⠔⢁⠔⢁⠔⢁│⣫⡾⣫⡾⣫⡾⣫⡾│⣡⠞⣡⠞⣡⠞⣡⠞│⡪⡪⡪⡪⡪⡪⡪⡪│⠛⣤⠛⣤⠛⣤⠛⣤│⣶⣿⠿⠛⣉⣤⣶⣿│     █  █ U+2039 203A █├‹─›┤█@LEFT/RIGHT SINGLE ANGLE QUOT. MK █ ·················································             ║══════════════════║                                                                                    38;2;255;255;0;46░░́░́́░́́́  ́ ́́ ́́́   
 █⡾⢟⣫⣵⡾⢟⣫⣵│⣫⢞⡵⣫⢞⡵⣫⢞│⠔⢁⠔⢁⠔⢁⠔⢁│⣫⡾⣫⡾⣫⡾⣫⡾│⣡⠞⣡⠞⣡⠞⣡⠞│⡪⡪⡪⡪⡪⡪⡪⡪│⠛⣤⠛⣤⠛⣤⠛⣤│⣉⣤⣶⣿⠿⠛⣉⣤│     █  █ U+00AB 00BB █├«─»┤█@LEFT/RIGHT DOUBLE ANGLE QUOT. MK █ ·················································             ║──────╳╮╮╭╳╭╲ mod ║
 █⡾⢟⣫⣵⡾⢟⣫⣵│⡵⣫⢞⡵⣫⢞⣫⢞│⠔⢁⠔⢁⠔⢁⠔⢁│⣫⡾⣫⡾⣫⡾⣫⡾│⣡⠞⣡⠞⣡⠞⣡⠞│⡪⡪⡪⡪⡪⡪⡪⡪│⠛⣤⠛⣤⠛⣤⠛⣤│⠿⠛⣉⣤⣶⣿⠿⠛│     █  █ U+2018 2019 █├‘─’┤█@LEFT/RIGHT SINGLE QUOTATION MARK █ ·················································             ║ Data ╰╯╲╳╰╳╳─╳╲─╲║─
─█────────│────────│────────┼────────┴────────│────────┼────────┼────────┼─────█  █ U+201C 201D █├“─”┤█@LEFT/RIGHT DOUBLE QUOTATION MARK █ ···················································             ║══════════════════║
 █«⡏⣇»⡏⣇⡏⣇⡏⣇│«⡏⣇»⡏⣇⡏⣇⡏⣇│«⡒⡆⣇⣓»⡒⡆⣇⣓│                 │                          │     █  █ U+201A 201B █├‚─‛┤█@LOW/HIGH-REVER-9 SINGLE QUOT. MK █ ·················································             ║▁▁▁▁╱▁╲╲╲▁╱▁╱▁▁ mode
 █⡏⣇⡏⣇⡏⣇⡏⣇│⣸⢹«»⣸⢹⣸⢹⣸⢹│⣇⣓⡒⡆«»⣇⣓⡒⡆│                                            │     █  █ U+201E 201F █├„─‟┤█@LOW/HIGH-REVER-9 DOUBLE QUOT. MK █ ·················································             ║ Data ╲╲▔╲╲▔╳▔▔▔▔▔║─
 █⡏⣇⡏⣇⡏⣇⡏⣇│⣇⡏⣇⡏⣇⡏⣇⡏│⡒⡆⣇⣓⡒⡆⣇⣓│                                            │     █  █ U+2E42 ██████├─⹂─┤█@LOW-REVERESED-9  DOUBLE QUOT. MK █ ·················································             ╚══════════════════╩═
 █⡏⣇⡏⣇⡏⣇⡏⣇│⢹⣸⢹⣸⢹⣸⢹⣸│⣇⣓⡒⡆⣇⣓⡒⡆│                          │                 │     █  █ U+275B 275C █├❛─❜┤█@HEAVY RGL/TURNED SINGLE COMMA MK █ ·················································
 █»44rˣc₂f⅝█»44i¹c₄f⅝█»48i⁴c₈f⅝█»  s c f █»  s c f █»  s c f █»  s c f █»  s c f ███████  █ U+275D 275E █├❝─❞┤█@HEAVY RGL/TURNED DOUBLE COMMA MK █ ···················································  
 ███████████████████████████████████████████████████████████████████████████████  █ U+275F 2760 █├❟─❠┤█@LOW HEAVY SINGLE/DOUBLE COMMA MK █ ···················································  
 ▅▅▅▅▅▅▅▅▅╵▅▅▅▅▅▅▅▅╵▅▅▅▅▅▅▅▅ ▅▅▅▅▅▅▅▅ ▅▅▅▅▅▅▅▅ ▅▅▅▅▅▅▅▅╵▅▅▅▅▅▅▅▅ ▅▅▅▅▅▅▅▅│▅▅▅▅▅▅  ████████████████████████████████████████████████████████ 
                                                                                                                                   [aug²³] 
                                                             
 ╔═════════════════╗                                             ⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤⣤░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░⣤       
 ║ PSEUDOCYRILLICS ║┌───────────────────────────────────────┐    ⣿⢰⠂COLORED SHAPES⠐⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒⠒░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░⡆⣿ 
 ║  ASCII CHARSET  ╠│ KOgOBA9 TA6JluLjA nCEBgOKuPuJlJluLjbI │    ⣿⢸██████████████████████████████████████████████████████████████████████░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░⡇⣿ 
 ╚═════════════════╝└───────────────────────────────────────┘    ⣿⢸█ ⭕ ⛔ █ 🔴 🟠 🟡 🟢 🔵 🟣 🟤 ⚫ ⚪ █ ♥️  ❤️  🧡 💛 💚 💙 💜 🤎 🖤 🤍 █░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░⡇⣿ 
   ║ А  A │ Д  g │ И  u │ Н  H │ С  C │ Х  X │ Щ  W,│ Э  3 ║     ⣿⢸██████████████████████████████████████████████████████████████████████░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░⡇⣿ 
   ║ Б  6 │ Е  E │ К  K │ О  O │ Т  T │ Ц Lj │ Ъ 'b │ Ю I0 ║     ⣿⢸█ 🟥 🟧 🟨 🟩 🟦 🟪 🟫 ◼️  🔳 ◻️  🔲 ██ ♦️  🔶 🔷 🔸🔹 🔺 🔻 █░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░ ⭐ ⚡ ♿ █⡇⣿ 
   ║ В  B │ Ж }}│{{│ Л Jl │ П  n │ У  y │ Ч  4 │ Ь  b │ Я  9 ║     ⣿⢸██████████████████████████████████████████████████████████████████████░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░⡇⣿ 
   ║ Г  r │ З  3 │ М  M │ Р  P │ Ф qp | Ш  W │ Ы bI ┌──────╨┐    ⣿⠸⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░⠇⣿ 
   ╚════════════════════════════════════════════════│ feb²⁴ │    ⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⠛⁽ᵐᵃʸ²³⁾░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░⠛       
                                                    └───────┘   
             
                                                                
"""  # noqa
# fmt: on

s = re.sub(
    "«([⠀-⣿]*)»",
    pt.Fragment(r"\1", pt.cvr.SKYLIGHT_BLUE).render() + pt.SeqIndex.HI_WHITE.assemble(),
    s,
)


def get_group_color(m):
    if m.groups("")[0] == "0.":
        return seq.YELLOW
    grp = int(m.group(2))
    if grp == 1:
        return seq.HI_RED
    elif 2 <= grp <= 3:
        return seq.HI_YELLOW
    elif grp == 4:
        return seq.HI_MAGENTA
    elif 5 <= grp <= 6:
        return seq.HI_GREEN
    elif grp == 7:
        return seq.HI_BLUE
    return seq.HI_WHITE


fmt_caption = autof(seq.CYAN + seq.build_c256(235, True))
fmt_bg = seq.CYAN
fmt_bg2 = seq.CYAN + seq.DIM
seq_bgbg = seq.build_c256(234, True)

s = re.sub(".*?", "", s)  #  aligner
s = re.sub(
    r"(█)([\dA-F])(█)",
    lambda m: "█"
    + f"{seq.CYAN}{seq.INVERSED}{seq.DIM}"
    + (m.group(2))
    + f"{seq.INVERSED_OFF}{seq.BOLD_DIM_OFF}█",
    s,
)
ln = 0


def color_braile2(m: re.Match):
    global ln
    char = 0
    for p in re.split("( )", m.group()):
        if p == "█" or p == " ":
            yield p
        else:
            char += 1
            yield (f"{p}", p)[char % 2]
    if not (ln := ln + 1) % 2:
        yield ""


s = re.sub("(?<=)(.+?)(?=)", lambda m: "".join(color_braile2(m)), s)


# s = re.sub(r'(V|var\. )?(\[\d+\]|<\w+>)([A-Za-z.-_ /]*)([A-Z )█])', lambda m:
#     autof(seq.CYAN)(m.group(1))+
#     autof(seq.YELLOW)(m.group(2))+
#     autof(seq.CYAN)(m.group(3)+m.group(4)), s)
s = re.sub(
    r"(v\. )?(\[(?:\d|N)+\]|<\w+>)([A-Za-z0-9. /\[\]]*)",
    lambda m: autof(seq.CYAN)(m.group(1) or "")
    + autof(seq.YELLOW)(m.group(2) or "")
    + autof(seq.CYAN)(m.group(3) or ""),
    s,
)

# s = re.sub(r'([^])(\b([\d])\b[^/█)\]])',
#                lambda m: m.group(1)+autof(get_group_color(m)+seq.BOLD)(m.group(2)),
#            s)
s = re.sub(r"(GRP|SGN)", lambda m: autof(seq.DIM + seq.CYAN + seq.INVERSED)(m.group(1)), s)
s = re.sub(
    r"(<\S+?)(d\w+?)@(.+?>)",
    autof(seq.BLUE)("\\1\\2") + "@" + autof(seq.BLUE + seq.DIM)("\\3"),
    s,
)
s = re.sub(r"\|\[([\w /,]+)]\|", lambda m: "█ " + m.group(1) + " █", s)
s = re.sub(r"([╆╈╅╊╄╇╃╉]+)", lambda m: fmt_group(m, seq.RED), s)
s = re.sub(r"([┲┢┪┱┺┡┩┹]+)", lambda m: fmt_group(m, seq.YELLOW), s)
s = re.sub(r"([╾╼╿╽]+)", lambda m: fmt_group(m, seq.MAGENTA), s)
s = re.sub(r"([┟┧┞┦┮┭┶┵]+)", lambda m: fmt_group(m, seq.GREEN), s)
s = re.sub(r"([┽╁╀┾]+)", lambda m: fmt_group(m, seq.BLUE), s)
s = re.sub(r"([┎┯┒┏┳┓┍┠┗┣┕┻┫┑┨┙┕┛┖┷┚┸┝┿┥╂┰╋]+)", lambda m: fmt_group(m, seq.CYAN), s)
s = re.sub(
    r"([\x1f\x15\x16]?[┌┬┐╒╤╕╓╥╖╔╦╗├┼┤╞╪╡╟╫╢╠╬╣└┴┘╘╧╛╙╨╜╚╩╝━═│─║┃╴╶╷╵╌┄┈╎┊┆╍┅┉╏┇┋╭╮╱╲╳╰╯]+)",
    lambda m: fmt_group(m, seq.WHITE),
    s,
)

# s = re.sub('▒+', lambda m: seq.RESET.print()+autof(seq.build_c256(232, False)).opening_str+(len(m.group(0))*'░') + fmt_caption.opening_str, s)
# s = re.sub('░+', lambda m: seq.RESET.print()+autof(seq.build_c256(23, False)).opening_str+(len(m.group(0))*'░') + fmt_caption.opening_str, s)

# first usage of look-behinds in regexps in my life
s = re.sub(
    "(?<=[^])█+",
    lambda m: seq.COLOR_OFF.print()
    + fmt_bg.opening_str
    + (len(m.group(0)) * "░")
    + seq.COLOR_OFF.print(),
    s,
)
s = re.sub(
    "(?<=[^])▓+",
    lambda m: seq.COLOR_OFF.print()
    + fmt_bg2.opening_str
    + (len(m.group(0)) * "░")
    + (seq.COLOR_OFF + seq.BOLD_DIM_OFF).print(),
    s,
)
# s = re.sub('(?<=[^])▒+', lambda m: seq.COLOR_OFF.print()+fmt_bg.opening_str+(len(m.group(0))*'⢕')+seq.COLOR_OFF.print(), s)
s = re.sub(
    "(?)(~+)",
    lambda m: seq.COLOR_OFF.print()
    + autof(seq.build_c256(236) + seq.INVERSED)(m.group(1) + (len(m.group(2)) * " ")),
    s,
)


# s = re.sub(r'(?:\x1b\\\x5b[0-9;]*m)?([A-Z]{4,})', lambda m: fmt_group(m, seq.OVERLINED+seq.HI_CYAN), s)
# s = re.sub(r'(\x1b\x5b[0-9;]*m)*(?:([A-Z]{4,}|BOX|&)|([A-Z (-][A-Za-z0-9,.:()/]+|   +[◀▶▲▼]|[◀▶▲▼]  +))',
s = re.sub(
    r"((\x1b\x5b[0-9;]*m)*)([@»]?)([:/]?)(?:((?<=[@»])[0-9A-Za-z¯×ˣ⁺¹²³⁰⁴-⁹₀-₉ .‥…_/\[\]↔-]+)|([A-Z.-]{4,}|BOX|&))",
    lambda m: (m.group(2) or "")
    + (("", "")[m.group(3) == "»"] if m.group(3) else "")
    + fmt_header(m.group(4) or "", autof(seq.GREEN))
    + fmt_header((m.group(6) or ""), autof(seq.OVERLINED + seq.HI_CYAN))
    + (("" + m.group(5) + "") if m.group(5) else ""),
    s,
)
s = re.sub(
    r"\x18(.+?)\x18",  # 
    lambda m: (
        seq.OVERLINED_OFF.assemble() + (autof(seq.CYAN + seq.DIM + seq.INVERSED)(m.group(1)))
        if m.group(1)
        else ""
    ),
    s,
)
s = re.sub(
    r"(░)(\x1b\x5b[0-9;]*m)*(\s?U\+)?(\s?[…,]?\s?[0-9A-F]{1,4}\s?)(#?\s?)(\s?[…,]\s?)?([0-9A-F]+\s?)?(\x1b\x5b[0-9;]*m)*(░)",
    lambda m: m.group(1)
    + ""
    + fmt.Format(seq.CYAN + seq.DIM + seq.INVERSED, hard_reset_after=True)(
        ""
        + (autof(92)("" + (m.group(3) or "")))
        + (seq.DIM + seq.BOLD + seq.CYAN).print()
        + m.group(4)
        + (autof(36)(m.group(6) or "") + (seq.CYAN).print())
        + (m.group(7) or "")
        + autof(seq.HI_CYAN)(((len(m.group(5)) - 1) * "?"))
    )
    + seq_bgbg.print()
    + (" " if len(m.group(5)) > 1 else "")
    + seq.RESET.print()
    + seq_bgbg.print()
    + m.group(8)
    + m.group(9)
    + "",
    s,
)
s = re.sub(
    r"(░)(\x1b\x5b[0-9;]*m)*([┌└│])(\x1b\x5b[0-9;]*m)*(░)",
    lambda m: (m.group(1) or "")
    + (m.group(2) or "")
    + f"{seq.RESET}{seq_bgbg}"
    + autof(seq.INVERSED + seq.CYAN + seq.DIM)(m.group(3))
    + (m.group(4) or "")
    + (m.group(5) or ""),
    s,
)


s = re.sub(
    r"((?:[¼½¾ʳˡˢᵇᵈᵐᵘᵣᶠₗₛ⅛⅜⅝⅞⅔]+)| U | P )",
    (ss := seq.CYAN + seq.DIM + seq.INVERSED).opening_str
    + ("\\1")
    + (seq.COLOR_OFF + seq.INVERSED_OFF + seq.BOLD_DIM_OFF).assemble(),
    s,
)
# s = re.sub(r'>(@+)(<?)', lambda m: (len(m.group(1)))*'▓', s)
s = re.sub(r"░(\x1b\x5b[0-9;]*m)*@(\x1b\x5b[0-9;]*m)*░", f"░{seq.RESET}█{seq_bgbg + seq.CYAN}░", s)
# language=regexp
any_ = R"(?:(?:\x1b\[[\d:;]*m)*)"
s = re.sub(
    rf"(?<=\S)({any_}*├{any_}*─*{any_}*)(.)({any_}*─*{any_}*)(?:(.)({any_}*─*))?({any_}*┤)(?=\S)",
    rf"{(q1:=seq.CYAN+seq.DIM)}\1{(q2:=seq.HI_WHITE+seq.BOLD)}\2{q1}\3{q2}\4{q1}\5{seq.BOLD_DIM_OFF}\6",
    s,
)

# s = re.sub(r'\x1d(\x1b.\[[0-9;]*m)?', lambda m: ''.join(m.groups(''))+seq.CYAN.print(), s)
s = re.sub(r"\x1e(.+?)\x1e", autof(seq_bgbg)("\\1"), s)  #  black bg
s = re.sub(
    r"(?)\x1f(.+?)\x1f(?)",
    autof(seq.CYAN + seq.DIM)("\\1" + autof(seq.INVERSED)("\\2") + "\\3"),
    s,
)  #   cyan inversed
s = re.sub(r"\x1d(.+?)\x1d", autof(seq.build_c256(238))("\\1"), s)  #  gray fg
s = re.sub(r"(?:\$)(ah\s+m\w+\s*\S*)", autof(seq.build_c256(237))(" \\1"), s)
s = re.sub(
    r"(?:([])|())(U)(\+)([A-Fa-f\d…]+)([])",
    lambda m: f'{seq.BOLD+seq.BG_BLACK+seq.GREEN+seq.build_c256(235,True)}{(m.group(1) or "")+(m.group(2) or "")}'
    f'{seq.INVERSED}{(m.group(3) or "")}'
    + f"{seq.DIM}{m.group(4)}{seq.CYAN}{m.group(5)}"
    + f"{seq.INVERSED_OFF}"
    + fmt_caption(m.group(6))
    + f"{seq.BOLD_DIM_OFF}",
    s,
)

s = re.sub(r"\x15", "", s)  # 
s = re.sub(r"\x16(.+?)\x16", autof(seq.CYAN + seq.DIM)(r"\1"), s)  # 
s = re.sub(
    r"\x19([0-9;]+)", lambda m: SequenceSGR(*(int(c) for c in m.group(1).split(";"))).assemble(), s
)  # 
s = re.sub(
    r"\x0e([0-9;]+)(.*?)\x0f",
    lambda m: autof(SequenceSGR(*(int(c) for c in m.group(1).split(";"))))(m.group(2)),
    s,
)  #  
s = re.sub(r"\x17", fmt_header(" ", autof(seq.CYAN + seq.DIM + seq.INVERSED)), s)  # 

# if common.get_terminal_width() < 140:
#    print(fmt.yellow('Table example truncated -- terminal is not wide enough (need 145+)'))
#    s = re.sub(r'\x1c.+', '', s)    #

s = re.sub("◊◊", "██", s)

# fmt: off
s = re.sub(
    "[{}]+".format(
        #
            "" """""""""""""" "" "\t"  ""  "" "" "\r" "" ""
        # [ 00][ 01][ 02][ 03][ 04][ 05][ 06][ 07][ 08][ 09][ 0a][ 0b][ 0c][ 0d][ 0e][ 0f][   ]
        #                                                     \n
        #
          """""""""""""""""" """"  ""  "" "" "" """"
        # [ 10][ 11][ 12][ 13][ 14][ 15][ 16][ 17][ 18][ 19][ 1a][ 1b][ 1c][ 1d][ 1e][ 1f][ 7f]
        #                                                         ESC
    ),
    "",
    s,
)
# fmt: on
print(s)


def lettersrow(sep="", pad=2):
    """
    @lettersrow()           ->      "123456789"
    @lettersrow("|")        ->      "1|2|3|4|5|6|7|8|9"
    @lettersrow(pad=1)      ->      "1 2 3 4 5 6 7 8 9"
    @lettersrow(pad=2)      ->      " 1  2  3  4  5  6  7  8  9 "
    @lettersrow("|", pad=2) ->      " 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9"
    """

    def decorator(__func):
        @functools.wraps(__func)
        def wrapper():
            pex = sep + ("", " ")[pad % 2]
            pin = pad // 2 * " "
            try:
                result = pex.join([pin + c + pin for c in __func()])
                return re.sub(r"\s{2,}", lambda m: "░" * len(m.group(0)), result)
            except StopIteration:
                return "<STOP>"

        return wrapper

    return decorator


@lettersrow("░", pad=0)
@autogen
def alnum_math():
    # fmt: off
    yield from [
        map(" ".join, zip("𝕬𝕭𝕮𝕯𝕰𝕱𝕲𝕳𝕴𝕵𝕶𝕷𝕸𝕹𝕺𝕻𝕼𝕽𝕾𝕿𝖀𝖁𝖂𝖃𝖄𝖅", "𝖆𝖇𝖈𝖉𝖊𝖋𝖌𝖍𝖎𝖏𝖐𝖑𝖒𝖓𝖔𝖕𝖖𝖗𝖘𝖙𝖚𝖛𝖜𝖝𝖞𝖟")),         # BOLD FRAKTUR
        map(" ".join, zip("𝒜ℬ𝒞𝒟ℰℱ𝒢ℋℐ𝒥𝒦ℒℳ𝒩𝒪𝒫ℛ𝒬𝒮𝒯𝒰𝒱𝒲𝒳𝒴𝒵", "𝒶𝒷𝒸𝒹ℯ𝒻ℊ𝒽𝒾𝒿𝓀𝓁𝓂𝓃ℴ𝓅𝓆𝓇𝓈𝓉𝓊𝓋𝓌𝓍𝓎𝓏")),   # SCRIPT
        map(" ".join, zip("𝓐𝓑𝓒𝓓𝓔𝓕𝓖𝓗𝓘𝓙𝓚𝓛𝓜𝓝𝓞𝓟𝓠𝓡𝓢𝓣𝓤𝓥𝓦𝓧𝓨𝓩", "𝓪𝓫𝓬𝓭𝓮𝓯𝓰𝓱𝓲𝓳𝓴𝓵𝓶𝓷𝓸𝓹𝓺𝓻𝓼𝓽𝓾𝓿𝔀𝔁𝔂𝔃")),        # BOLD SCRIPT
        map(" ".join, zip("𝐴𝐵𝐶𝐷𝐸𝐹𝐺𝐻𝐼𝐽𝐾𝐿𝑀𝑁𝑂𝑃𝑄𝑅𝑆𝑇𝑈𝑉𝑊𝑋𝑌𝑍", "𝑎𝑏𝑐𝑑𝑒𝑓𝑔ℎ𝑖𝑗𝑘𝑙𝑚𝑛𝑜𝑝𝑞𝑟𝑠𝑡𝑢𝑣𝑤𝑥𝑦𝑧")),  # ITALIC
        map(" ".join, zip("𝑨𝑩𝑪𝑫𝑬𝑭𝑮𝑯𝑰𝑱𝑲𝑳𝑴𝑵𝑶𝑷𝑸𝑹𝑺𝑻𝑼𝑽𝑾𝑿𝒀𝒁", "𝒂𝒃𝒄𝒅𝒆𝒇𝒈𝒉𝒊𝒋𝒌𝒍𝒎𝒏𝒐𝒑𝒒𝒓𝒔𝒕𝒖𝒗𝒘𝒙𝒚𝒛")),  # BOLD ITALIC
        map(" ".join, zip("𝘈𝘉𝘊𝘋𝘌𝘍𝘎𝘏𝘐𝘑𝘒𝘓𝘔𝘕𝘖𝘗𝘘𝘙𝘚𝘛𝘜𝘝𝘞𝘟𝘠𝘡", "𝘢𝘣𝘤𝘥𝘦𝘧𝘨𝘩𝘪𝘫𝘬𝘭𝘮𝘯𝘰𝘱𝘲𝘳𝘴𝘵𝘶𝘷𝘸𝘹𝘺𝘻")),  # SANS-SERIF ITALIC
        map(" ".join, zip("𝘼𝘽𝘾𝘿𝙀𝙁𝙂𝙃𝙄𝙅𝙆𝙇𝙈𝙉𝙊𝙋𝙌𝙍𝙎𝙏𝙐𝙑𝙒𝙓𝙔𝙕", "𝙖𝙗𝙘𝙙𝙚𝙛𝙜𝙝𝙞𝙟𝙠𝙡𝙢𝙣𝙤𝙥𝙦𝙧𝙨𝙩𝙪𝙫𝙬𝙭𝙮𝙯")),  # SANS-SERIF BOLD ITALIC
        map(" ".join, zip("𝔸𝔹ℂ𝔻𝔼𝔽𝔾ℍ𝕀𝕁𝕂𝕃𝕄ℕ𝕆𝕇ℚℝ𝕊𝕋𝕌𝕍𝕎𝕏𝕐ℤ", "𝕒𝕓𝕔𝕕𝕖𝕗𝕘𝕙𝕚𝕛𝕜𝕝𝕞𝕟𝕠𝕡𝕢𝕣𝕤𝕥𝕦𝕧𝕨𝕩𝕪𝕫")),  # DOUBLE-STRUCK
        map(" ".join, zip("𝐀𝐁𝐂𝐃𝐄𝐅𝐆𝐇𝐈𝐉𝐊𝐋𝐌𝐍𝐎𝐏𝐐𝐑𝐒𝐓𝐔𝐕𝐖𝐗𝐘𝐙", "𝐚𝐛𝐜𝐝𝐞𝐟𝐠𝐡𝐢𝐣𝐤𝐥𝐦𝐧𝐨𝐩𝐪𝐫𝐬𝐭𝐮𝐯𝐰𝐱𝐲𝐳")),  # BOLD
        map(" ".join, zip("𝖠𝖡𝖢𝖣𝖤𝖥𝖦𝖧𝖨𝖩𝖪𝖫𝖬𝖭𝖮𝖯𝖰𝖱𝖲𝖳𝖴𝖵𝖶𝖷𝖸𝖹", "𝖺𝖻𝖼𝖽𝖾𝖿𝗀𝗁𝗂𝗃𝗄𝗅𝗆𝗇𝗈𝗉𝗊𝗋𝗌𝗍𝗎𝗏𝗐𝗑𝗒𝗓")),  # SANS-SERIF
        map(" ".join, zip("𝗔𝗕𝗖𝗗𝗘𝗙𝗚𝗛𝗜𝗝𝗞𝗟𝗠𝗡𝗢𝗣𝗤𝗥𝗦𝗧𝗨𝗩𝗪𝗫𝗬𝗭", "𝗮𝗯𝗰𝗱𝗲𝗳𝗴𝗵𝗶𝗷𝗸𝗹𝗺𝗻𝗼𝗽𝗾𝗿𝘀𝘁𝘂𝘃𝘄𝘅𝘆𝘇")),  # SANS-SERIF BOLD
        map(" ".join, zip("𝙰𝙱𝙲𝙳𝙴𝙵𝙶𝙷𝙸𝙹𝙺𝙻𝙼𝙽𝙾𝙿𝚀𝚁𝚂𝚃𝚄𝚅𝚆𝚇𝚈𝚉", "𝚊𝚋𝚌𝚍𝚎𝚏𝚐𝚑𝚒𝚓𝚔𝚕𝚖𝚗𝚘𝚙𝚚𝚛𝚜𝚝𝚞𝚟𝚠𝚡𝚢𝚣")),  # MONOSPACE
    ]
    # fmt: on


@lettersrow("", pad=0)
@autogen
def small_caps():
    yield " ᴀ ░ ʙ ░ ᴄ ░ ᴅ ░ ᴇ ░ ꜰ ░ ɢ ░ ʜ ░ ɪ ░ ᴊ ░ ᴋ ░ ʟ ░ ᴍ ░ ɴ ░ ᴏ ░ ᴘ ░░░░░ ʀ ░ ꜱ ░ ᴛ ░ ᴜ ░ ᴠ ░ ᴡ ░░░░░ ʏ ░ ᴢ "


@lettersrow("░", pad=0)
@autogen
def supsub_letters():
    def __wrap(v: str) -> str:
        yield from [(" ", "░")[len([L for L in v if L == "░"]) > 0].join(v) for v in pt.chunk(v, 2)]

    yield __wrap("ᴬᵃᴮᵇ░ᶜᴰᵈᴱᵉ░ᶠᴳᵍᴴʰᴵⁱᴶʲᴷᵏᴸˡᴹᵐᴺⁿᴼᵒᴾᵖ░░ᴿʳ░ˢᵀᵗᵁᵘⱽᵛᵂʷ░ˣ░ʸ░ᶻ")
    yield __wrap("░ₐ░░░░░░░ₑ░░░░░ₕ░ᵢ░ⱼ░ₖ░ₗ░ₘ░ₙ░ₒ░ₚ░░░ᵣ░ₛ░ₜ░ᵤ░ᵥ░░░ₓ░░░░")


@lettersrow("░", pad=0)
@autogen
def combining():
    def __wrap(v: tuple[str, ...]) -> str:
        if len(v) < 3:
            return "░".join(map(lambda L: "◌" + L if L else "░", v))
        return "◌".join(["", *v])

    yield [
        __wrap(v)
        for (_, v) in {
            "a": ("", "\u0363"),
            "b": ("", "\u1DE8"),
            "c": ("", "\u0368"),
            "d": ("", "\u0369"),
            "e": ("", "\u0364"),
            "f": ("", "\u1DEB"),
            "g": ("\u1DDB", "\u1DDA"),
            "h": ("", "\u036A"),
            "i": ("", "\u0365"),
            "j": ("", ""),
            "k": ("", "\u1DDC"),
            "l": ("\u1dde", "\u1DDD"),
            "m": ("\u1ddf", "\u036B"),
            "n": ("\u1de1", "\u1de0"),
            "o": ("", "\u0366"),
            "p": ("", "\u1DEE"),
            "q": ("", ""),
            "r": ("\u1de2", "\u036C", "\u1dca"),
            "s": ("", "\u1de4"),
            "t": ("", "\u036D"),
            "u": ("", "\u0367"),
            "v": ("", "\u036E"),
            "w": ("", "\u1DF1"),
            "x": ("", "\u036F"),
            "y": ("", ""),
            "z": ("", "\u1de6"),
        }.items()
    ]


@lettersrow("", pad=0)
@autogen
def enclosed_alnum():
    yield "🄐 ⒜░🄑 ⒝░🄒 ⒞░🄓 ⒟░🄔 ⒠░🄕 ⒡░🄖 ⒢░🄗 ⒣░🄘 ⒤░🄙 ⒥░🄚 ⒦░🄛 ⒧░🄜 ⒨░🄝 ⒩░🄞 ⒪░🄟 ⒫░🄠 ⒬░🄡 ⒭░🄢 ⒮░🄣 ⒯░🄤 ⒰░🄥 ⒱░🄦 ⒲░🄧 ⒳░🄨 ⒴░🄩 ⒵"
    yield " 🅐 ░ 🅑 ░ 🅒 ░ 🅓 ░ 🅔 ░ 🅕 ░ 🅖 ░ 🅗 ░ 🅘 ░ 🅙 ░ 🅚 ░ 🅛 ░ 🅜 ░ 🅝 ░ 🅞 ░ 🅟 ░ 🅠 ░ 🅡 ░ 🅢 ░ 🅣 ░ 🅤 ░ 🅥 ░ 🅦 ░ 🅧 ░ 🅨 ░ 🅩 "
    yield "Ⓐ ⓐ Ⓑ ⓑ Ⓒ ⓒ Ⓓ ⓓ Ⓔ ⓔ Ⓕ ⓕ Ⓖ ⓖ Ⓗ ⓗ Ⓘ ⓘ Ⓙ ⓙ Ⓚ ⓚ Ⓛ ⓛ Ⓜ ⓜ Ⓝ ⓝ Ⓞ ⓞ Ⓟ ⓟ Ⓠ ⓠ Ⓡ ⓡ Ⓢ ⓢ Ⓣ ⓣ Ⓤ ⓤ Ⓥ ⓥ Ⓦ ⓦ Ⓧ ⓧ Ⓨ ⓨ Ⓩ ⓩ"
    yield " 🄰 ░ 🄱 ░ 🄲 ░ 🄳 ░ 🄴 ░ 🄵 ░ 🄶 ░ 🄷 ░ 🄸 ░ 🄹 ░ 🄺 ░ 🄻 ░ 🄼 ░ 🄽 ░ 🄾 ░ 🄿 ░ 🅀 ░ 🅁 ░ 🅂 ░ 🅃 ░ 🅄 ░ 🅅 ░ 🅆 ░ 🅇 ░ 🅈 ░ 🅉 "
    yield " 🅰 ░ 🅱 ░ 🅲 ░ 🅳 ░ 🅴 ░ 🅵 ░ 🅶 ░ 🅷 ░ 🅸 ░ 🅹 ░ 🅺 ░ 🅻 ░ 🅼 ░ 🅽 ░ 🅾 ░ 🅿 ░ 🆀 ░ 🆁 ░ 🆂 ░ 🆃 ░ 🆄 ░ 🆅 ░ 🆆 ░ 🆇 ░ 🆈 ░ 🆉 "


@lettersrow("░", pad=2)
@autogen
def fraktur_letters():
    yield "𝔄𝔅ℭ𝔇𝔈𝔉𝔊ℌℑ𝔍𝔎𝔏𝔐𝔑𝔒𝔓𝔔ℜ𝔖𝔗𝔘𝔙𝔚𝔛𝔜ℨ"


@lettersrow("", pad=0)
@autogen
def digits():
    yield " ░⑴░⑵░⑶░⑷░⑸░⑹░⑺░⑻░⑼░⑽"
    yield "⑾░⑿░⒀░⒁░⒂░⒃░⒄░⒅░⒆░⒇░"
    yield "⓿░❶░❷░❸░❹░❺░❻░❼░❽░❾░❿"
    yield "⓫░⓬░⓭░⓮░⓯░⓰░⓱░⓲░⓳░⓴░"
    yield " #⓵#⓶#⓷#⓸#⓹#⓺#⓻#⓼#⓽#⓾"
    yield "🄋#➀#➁#➂#➃#➄#➅#➆#➇#➈#➉"
    yield "🄌#➊#➋#➌#➍#➎#➏#➐#➑#➒#➓"


@lettersrow("", pad=0)
@autogen
def migits():
    yield "𝟘░𝟙░𝟚░𝟛░𝟜░𝟝░𝟞░𝟟░𝟠░𝟡░░"  # DOUBLE-STRUCK
    yield "𝟎░𝟏░𝟐░𝟑░𝟒░𝟓░𝟔░𝟕░𝟖░𝟗░░"  # BOLD
    yield "𝟢░𝟣░𝟤░𝟥░𝟦░𝟧░𝟨░𝟩░𝟪░𝟫░░"  # SANS-SERIF
    yield "𝟬░𝟭░𝟮░𝟯░𝟰░𝟱░𝟲░𝟳░𝟴░𝟵░░"  # SANS-SERIF BOLD
    yield "𝟶░𝟷░𝟸░𝟹░𝟺░𝟻░𝟼░𝟽░𝟾░𝟿░░"  # MONOSPACE
    yield "０１２３４５６７８９"  # FULLWIDTH


@lettersrow("", pad=0)
@autogen
def flstp():
    yield "🄀#⒈#⒉#⒊#⒋#⒌#⒍#⒎#⒏#⒐#⒑"
    yield "⒒#⒓#⒔#⒕#⒖#⒗#⒘#⒙#⒚#⒛#"


@lettersrow("", pad=0)
@autogen
def cigits():
    yield "⓪░①░②░③░④░⑤░⑥░⑦░⑧░⑨░⑩"
    yield "⑪░⑫░⑬░⑭░⑮░⑯░⑰░⑱░⑲░⑳░"
    yield "㉑㉒㉓㉔㉕㉖㉗㉘㉙㉚"
    yield "㉛㉜㉝㉞㉟㊱㊲㊳㊴㊵"
    yield "㊶㊷㊸㊹㊺㊻㊼㊽㊾㊿"


@lettersrow("", pad=0)
@autogen
def fullwidth():
    yield "ＡａＢｂＣｃＤｄＥｅＦｆＧｇＨｈＩｉＪｊＫｋＬｌＭｍＮｎＯｏＰｐＱｑＲｒＳｓＴｔＵｕＶｖＷｗＸｘＹｙＺｚ"


ssc = (
    rf"""
                  ]▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒░                                                                     
                  ]▒▒░ SUPER-/SUBSCRIPTS, ENCLOSED AND MATH ALPHANUMERICS ]▒▒▒░                                                                     
                  ]▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒░                                                                          
                  ]▒▒▒ A ▒ B ▒ C ▒ D ▒ E ▒ F ▒ G ▒ H ▒ I ▒ J ▒ K ▒ L ▒ M ▒ N ▒ O ▒ P ▒ Q ▒ R ▒ S ▒ T ▒ U ▒ V ▒ W ▒ X ▒ Y ▒ Z ▒▒▒ 0 1 2 3 4 5 6 7 8 9 ↑ ▒▒ 1 2 3 4 5 6 7 8 9 ↟ ▒▒▒░                                                                          
                  ]▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒███████████████@                                                               
      Superscripts]▒▒░{                                                                                     supsub_letters()}░░░░⁰░¹░²░³░⁴░⁵░⁶░⁷░⁸░⁹░░]▒▒░       ]██@⁺@⁻@⁼@⁽@⁾]██@  Super-/subscript                                  
        Subscripts]▒▒░{                                                                                     supsub_letters()}░░░░₀░₁░₂░₃░₄░₅░₆░₇░₈░₉░⏨]▒▒░       ]██@₊@₋@₌@₍@₎]██@  punctuation                                               
       ◌ Combining]▒▒░{                                                                                          combining()}]███████████████████████████████████████████████████@                                                  
        Small caps]▒▒░{                                                                                         small_caps()}]██@↉@½@⅓@¼@⅕@⅙@⅐@⅛@⅑@⅒@⅔@⅖@¾@⅗@⅜@⅘@⅚@⅝@⅞]██@‰@‱@]██@  Fractions                                       
                  ]▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒]███████████████████████████████████████████████████@                                                 
     Parenthesized]▒▒░{                                                                                     enclosed_alnum()}░░░░{           digits()}░░░░{          digits()}]▒▒░                                                   
   Negated circled]▒▒░{                                                                                     enclosed_alnum()}░░░░{           digits()}░░░░{          digits()}]▒▒░                                                     
           Circled]▒▒░{                                                                                     enclosed_alnum()}░░░░{           cigits()}░░░░{          cigits()}]▒▒░                                      
           Squared]▒▒░{                                                                                     enclosed_alnum()}]▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓░{          cigits()}]▒▒░                                                  
   Negated squared]▒▒░{                                                                                     enclosed_alnum()}]▓▓#{           digits()}]▓▓░{          cigits()}]▒▒░  Double circled                                  
                  ]▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒]▓▓#{           digits()}]▓▓░{          cigits()}]▒▒░  Circled s-s                                     
           Fraktur]▒▒░{                                                                                    fraktur_letters()}]▓▓#{           digits()}]▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓#  Neg. circ. s-s                                  
      Bold fraktur]▒▒░{                                                                                         alnum_math()}]▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓#                                               
            Script]▒▒░{                                                                                         alnum_math()}]▓▓#{            flstp()}####{           flstp()}]▓▓#  Full stop                                                    
       Bold script]▒▒░{                                                                                         alnum_math()}]▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓#                                       
            Italic]▒▒░{                                                                                         alnum_math()}]▓▓##################################################                                                  
       Bold Italic]▒▒░{                                                                                         alnum_math()}]▒▒░
       S.s. italic]▒▒░{                                                                                         alnum_math()}]▒▒░
  S.s. bold italic]▒▒░{                                                                                         alnum_math()}]▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒░                                                                          
     Double-struck]▒▒░{                                                                                         alnum_math()} ░░░{           migits()}]▒▒░                                                                           
              Bold]▒▒░{                                                                                         alnum_math()} ░░░{           migits()}]▒▒░  GREEK       ᵋ ᶿ ᶥ ᶹ ᵝ ᵞ ᵟ ᵠ ᵡ ᵦ ᵧ ᵨ ᵩ                                    
        Sans-serif]▒▒░{                                                                                         alnum_math()} ░░░{           migits()}]▒▒░                                                                           
   Sans-serif bold]▒▒░{                                                                                         alnum_math()} ░░░{           migits()}]▒▒░  CYRILLIC  АБВГДЕЖЗИЙКЛМНОПРСТУфХЦЧШЩЪЫЬЭЮЯ                               
         Monospace]▒▒░{                                                                                         alnum_math()} ░░░{           migits()}]▒▒░                                                                           
         Fullwidth]▒▒░{                                                                                           fullwidth()}░░░{          migits()} ]▒▒░            -_ⷠ_ⷡ_ⷢ_ⷣ_ⷷ_ⷤ_ⷥ_ꙵ-_ⷦ_ⷧ_ⷨ_ⷩ_ⷪ_ⷫ_ⷬ_ⷭ_ⷮ_ꙷ_ꚞ_ⷯ_ⷰ_ⷱ_ⷲ_ⷳ_ꙸ_ꙹ_ꙺ-_ⷻ-   
                  ]▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒░   @TODO    -------------ᵸ------------ꚜ-ꚝ---                              
                   ░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░[may²⁴]░                                                                          
"""
    + r"""


(?m)^(.{18})[34m\1[39;22m
(?<=[▒█])( .{1,2} |[\d +*↑↟]+)(?=[▒▓])	[1;44;38;5;15m\1[;94m
([ℎℬℰℱℋℐℒℳℛℯℊℴℭℌℑℜℨℂℍℕℙℚℝℤ]|<Irregular>)[33m\1[39m
([\u1DD0-\u1DFF]|<Limited support>)[31m\1[39m
(Super-/subscript|punctuation)[95m\1[39m
(Fractions)[35m\1[39m
(Full stop)[36m\1[39m
(Double circled)[36m\1[39m
(?i)(((neg. )?circ(?:\.|led) s-s))[96m\1[39m
(Higher order)[96m\1[39m

(?<=[ ░])(\[)	[34;2m▏[39;22m
(?<=[▒])(\[)	[34;1m▏[39;22m
(?<=[▓])(\[)	[36m▏[39;22m
(?<=[█])(\[)	[35m▏[39;22m
(\])(?=[ ░])		[34;2m▕[39;22m
(\])(?=[▒])		[34;1m▕[39;22m
(\])(?=[▓])		[36m▕[39;22m
(\])(?=[█])		[35m▕[39;22m
(?<=[ ░])(\])	[34;2m▕[39;22m
(?<=[▒])(\])	[34;1m▕[39;22m
(?<=[▓])(\])	[36m▕[39;22m
(?<=[█])(\])	[35m▕[39;22m
(\[)(?=[ ░])		[34;2m▏[39;22m
(\[)(?=[▒])		[34;1m▏[39;22m
(\[)(?=[▓])		[36m▏[39;22m
(\[)(?=[█])		[35m▏[39;22m

\|							[34m│[39m

(?<=░)(;)		  			[34m▍[39m
(?<=▒)(;)					[24;94m▍[39m

(?<=▒)(---)(?=▒)			[94m[53m▒▒▒[55m[m
(?<=▒)(-)(?=▒)				[94m[53m▒[55m[m
([▒░]+)						[34m\1[39m

(#)							[36m░[39m
(@)							[35m░[39m
(▓)							[36m▒[39m
(█)							[35m▒[39m

([╔╦╗╠╬╣╚╩╝═║])	[32m\1[39m



                                                 unstable char width  
(ꟲ)		[117G[94m\1[m                                             
(ꟳ)		[121G[94m\1[m                               ◌ᪿ            
(ꟴ)		[125G[94m\1[m
(𐞥)		[129G[94m\1[m

⥀ can be invisible ⇉ *  ꟲ   ꟳ   ꟴ   𐞥               
                               
Circled on b. square  ▒▎ U+324x │㉈ ㉉ ㉊ ㉋ ㉌ ㉍ ㉎ ㉏
░░░░░░░░░░░░░░░░░░░░░░░░░⇈  unstable char width ⥀░░░░░░░▎
                                                 [dec²³]



"""
)
TemplateCommand(ssc).run()

if tmp_file:
    tmp_file.flush()
    Pager().open(tmp_file)


###################################################################################
##/¯¯¯¯¯¯/#########################################################################  ``10´ .....
#####/  /##/""""/######################################################### ..... ##     ::    :: ::::8 .....
####/  /##/ """/########################################################## ::... ##  ::::: ::9:: ...:: ^^^7: ''':. °°::
###/__/##/""" /########################################################### ...:: ##     ::    :: ''':: ^^^:: ''':: °°::
###################################################################################  ::::: ::::: ::::: ::::: 6:::' °°°
## This file is a part of my long-term experiment named "Legacy code -- How bad  ##  ..... ''::. ....  ::::: ....  ....
## can it be?" (tentative assessment: worse than a nightmare) and is maintained  ##  ^^^:: ..9'' ''':: ...:: ...6: ..::
## in a special way, specifically with this rule in mind:                        ##  ...:1 ''::. ''':8 ...7: ...:: ..:5
##    +--------------------------------------------------------------------------##  ^^^:0 :::'' ::::' ''''' ''''
##    │ Updating and bug fixing should be done by adding new lines; changing the ##  ...::
##    │ existing ones is prohibited unless it's the only possible way to proceed ##  °°°°°


# ░░ #SUBSCRIPTS AND SUPERSCRIPTS# ░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░│  ░░ #ENCLOSED ALPHANUMERICS# ░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░│
# ░░▴░░░░░░░░░░░░░░░░░░░░░░░░░░░░░▵░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░│  ░░▴░░░░░░░░░░░░░░░░░░░░░░░░▵░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░│
# ░░▲▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒«░░▲▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒«░░░│  ░░▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▍░░│
# ░░▒▒~PRIMARY~▒▒ 0 ▒ 1 ▒ 2 ▒ 3 ▒ 4 ▒ 5 ▒ 6 ▒ 7 ▒ 8 ▒ 9 ▒ A ▒ B ▒ C ▒ D ▒ E ▒ F ▒▒▒▍░░▒▒~SUPPLEMENT~▒▒▎░ ᪲░░᪲░▒▒▒▒▒~GREEK  ~▒▒▍░░░│  ░░▒▒▎Circled digits            │  U+246x │⓪░①░②░③░④░⑤░⑥░⑦░⑧░⑨░⑩░▒ 00 ▒▍░░│
# ░░▒▒▲▒▒▒▒▒▒▒△▒▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒▒▒▍░░▒▒▲▒▒▒▒▒▒▒▒▒▒△▒▒▒▒▒▒▒▒▒▒▒▒▒~LETTERS~▒▒▍░░░│  ░░▒▒▎                          │  U+247x │░░⑪░⑫░⑬░⑭░⑮░⑯░⑰░⑱░⑲░⑳░▒ 10 ▒▍░░│
# ░░▒▒▎ U+00Bx │░░░░░░░░░ ² ░ ³ ░░░░░░░░░░░░░░░░░░░░░ ¹ ░░░░░░░░░░░░░░░░░░░░░░░░░▒▒▍░░▒▒▎░¼░½░¾░⅐░⅑░⅒░⅓░⅔░⅕░▒▒▒▒▒▲▒▒▒▒▒▒▒△▒▒▍░░░│  ░░▒▒▎                          │  U+325x │░░㉑㉒㉓㉔㉕㉖㉗㉘㉙㉚▒ 20 ▒▍░░│
# ░░▒▒▎ U+207x │░ ⁰ ░[ⁱ]░░░░░░░░░ ⁴ ░ ⁵ ░ ⁶ ░ ⁷ ░ ⁸ ░ ⁹ ░ ⁺ ░ ⁻ ░ ⁼ ░ ⁽ ░ ⁾ ░ ⁿ ░▒▒▍░░▒▒▎░⅖░⅗░⅘░⅙░⅚░⅛░⅜░⅝░⅞░▒▒▎░░ᵋ░ᶿ░ᶥ░ᶹ░░▒▒▍░░░│  ░░▒▒▎                          │  U+325x │░░㉛㉜㉝㉞㉟㊱㊲㊳㊴㊵▒ 30 ▒▍░░│
# ░░▒▒▎ U+208x │░ ₀ ░ ₁ ░ ₂ ░ ₃ ░ ₄ ░ ₅ ░ ₆ ░ ₇ ░ ₈ ░ ₉ ░ ₊ ░ ₋ ░ ₌ ░ ₍ ░ ₎ ░░░░░▒▒▍░░▒▒▎░⅟░↉░‰░‱░℀░℁░℅░℆░⅍░▒▒▎░ᵝ░ᵞ░ᵟ░ᵠ░ᵡ░▒▒▍░░░│  ░░▒▒▎                          │  U+32Bx │░░㊶㊷㊸㊹㊺㊻㊼㊽㊾㊿▒ 40 ▒▍░░│
# ░░▒▒▎ U+209x │░ ₐ ░ ₑ ░ ₒ ░ ₓ ░ ₔ ░ ₕ ░ ₖ ░ ₗ ░ ₘ ░ ₙ ░ ₚ ░ ₛ ░ ₜ ░░░░░░░░░░░░░▒▒▍░░▒▒▎░©░®░№░℠░™░🅪 🅫 🅬░⏨░▒▒▎░ᵦ░ᵧ░ᵨ░ᵩ░ᵪ░▒▒▍░░░│  ░░▒▒▎Double circled digits     │  U+24Fx │░░⓵░⓶░⓷░⓸░⓹░⓺░⓻░⓼░⓽░⓾░▒▒▒▒▒▒▍░░│
# ░░▒▒▲▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒△▒▒▍░░▒▒▲▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒△▒▒▒▒▒▒▒▲▒▒▒▒▒▒▒△▒▒▍░░░│  ░░▒▒▎Parenthesized digits      │  U+247x │░░⑴░⑵░⑶░⑷░⑸░⑹░⑺░⑻░⑼░⑽░▒ 00 ▒▍░░│
# ░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░│  ░░▒▒▎                          │  U+248x │░░⑾░⑿░⒀░⒁░⒂░⒃░⒄░⒅░⒆░⒇░▒ 10 ▒▍░░│
# ░░▲▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒«░▒▒▎Negative circled digits   │  U+277x │⓿░❶░❷░❸░❹░❺░❻░❼░❽░❾░❿░▒ 00 ▒▍░░│
# ░░▒▒~LATIN LETTERS~▒▒▒▒ A ▒ B ▒ C ▒ D ▒ E ▒ F ▒ G ▒ H ▒ I ▒ J ▒ K ▒ L ▒ M ▒ N ▒ O ▒ P ▒ Q ▒ R ▒ S ▒ T ▒ U ▒ V ▒ W ▒ X ▒ Y ▒ Z ▒▒▒▍░▒▒▎                          │  U+24Fx │░░⓫░⓬░⓭░⓮░⓯░⓰░⓱░⓲░⓳░⓴░▒ 10 ▒▍░░│
# ░░▒▒▲▒▒▒▒▒▒▒▒▒▒▒▒▒△▒▒▒▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒---▒▒▒▍░▒▒▎Circled sans-serif dig.   │  U+278x │🄋░➀░➁░➂░➃░➄░➅░➆░➇░➈░➉░▒▒▒▒▒▒▍░░│
# ░░▒▒▎Small capitals   │ ᴀ ░ ʙ ░ ᴄ ░ ᴅ ░ ᴇ ░ ꜰ ░ ɢ ░ ʜ ░ ɪ ░ ᴊ ░ ᴋ ░ ʟ ░ ᴍ ░ ɴ ░ ᴏ ░ ᴘ ░░░░░ ʀ ░ ꜱ ░ ᴛ ░ ᴜ ░ ᴠ ░ ᴡ ░░░░░ ʏ ░ ᴢ │▒▒▍░▒▒▎Negative circl. s-s dig.  │  U+279x │🄌░➊░➋░➌░➍░➎░➏░➐░➑░➒░➓░▒▒▒▒▒▒▍░░│
# ░░▒▒▎Superscript cap. │ ᴬ ░ ᴮ ░ * ░ ᴰ ░ ᴱ ░ * ░ ᴳ ░ ᴴ ░ ᴵ ░ ᴶ ░ ᴷ ░ ᴸ ░ ᴹ ░ ᴺ ░ ᴼ ░ ᴾ ░ * ░ ᴿ ░░░░░ ᵀ ░ ᵁ ░ ⱽ ░ ᵂ ░░░░░░░░░░░░│▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒«
# ░░▒▒▎Superscript min. │ ᵃ ░ ᵇ ░ ᶜ ░ ᵈ ░ ᵉ ░ ᶠ ░ ᵍ ░ ʰ ░ ⁱ ░ ʲ ░ ᵏ ░ ˡ ░ ᵐ ░ ⁿ ░ ᵒ ░ ᵖ ░ * ░ ʳ ░ ˢ ░ ᵗ ░ ᵘ ░ ᵛ ░ ʷ ░ ˣ ░ ʸ ░ ᶻ │▒▒▒▒▒▒▎Parenthesized small let.  │  U+249x │░⒜⒝⒞⒟⒠⒡⒢⒣⒤⒥⒦⒧⒨⒩⒪⒫⒬⒭⒮⒯⒰⒱⒲⒳⒴⒵░▒▒▒▍
# ░░▒▒▎Overscript cap. ◌│░░░░░░░░░░░░░░░░░░░░░░░░ ◌ᷛ ░░░░░░░░░░░░░░░░░ ◌ᷞ ░ ◌ᷟ ░ ◌ᷡ ░░░░░░░░░░░░░ ◌ᷢ ░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░│▒▒▒▒▒▒▎Circled capitals          │  U+24Bx │░ⒶⒷⒸⒹⒺⒻⒼⒽⒾⒿⓀⓁⓂⓃⓄⓅⓆⓇⓈⓉⓊⓋⓌⓍⓎⓏ░▒▒▒▍
# ░░▒▒▎Overscript min. ◌│ ◌ͣ ░ ◌ᷨ ░ ◌ͨ ░ ◌ͩ ░ ◌ͤ ░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░│▒▒▒▒▒▒▎Circled small letters     │  U+24Dx │░ⓐⓑⓒⓓⓔⓕⓖⓗⓘⓙⓚⓛⓜⓝⓞⓟⓠⓡⓢⓣⓤⓥⓦⓧⓨⓩ░▒▒▒▍
# ░░▒▒▎Underscript min.◌│░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░ ◌᷊ ░░░░░░░░░░░░░░░░░ * ░░░░░░░░░░░░│▒▒▒▒▒▒▎Parenthesized capitals    │ U+1F11x │░🄐🄑🄒🄓🄔🄕🄖🄗🄘🄙🄚🄛🄜🄝🄞🄟🄠🄡🄢🄣🄤🄥🄦🄧🄨🄩░▒▒▒▍
# ░░▒▒▎Subscript min.   │ ₐ ░░░░░░░░░░░░░ ₑ ░░░░░░░░░ ₕ ░ ᵢ ░ ⱼ ░ ₖ ░ ₗ ░ ₘ ░ ₙ ░ ₒ ░ ₚ ░░░░░ ᵣ ░ ₛ ░ ₜ ░ ᵤ ░ ᵥ ░░░░░ ₓ ░░░░░░░░│▒▒▒▒▒▒▎Squared capitals          │ U+1F13x │░🄰🄱🄲🄳🄴🄵🄶🄷🄸🄹🄺🄻🄼🄽🄾🄿🅀🅁🅂🅃🅄🅅🅆🅇🅈🅉░▒▒▒▍
# ̵̲░░⃘̥▒▒▎                 │̵̲░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░⃘│̥▒▒▒▒▒▒▎Negative circled capitals │ U+1F15x │░🅐🅑🅒🅓🅔🅕🅖🅗🅘🅙🅚🅛🅜🅝🅞🅟🅠🅡🅢🅣🅤🅥🅦🅧🅨🅩░▒▒▒▍
# ░░▒▒▎Math. fraktur    │𝔄 𝔅 ░ 𝔇 𝔈 𝔉 𝔊 ░ 𝔍 𝔎 𝔏 𝔐 𝔑 𝔒 𝔓 𝔔   ░ 𝔖 𝔗 𝔘 𝔙 𝔚 𝔛 𝔜 ░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░▒▒▒▒▒▒▎Negative squared capitals │ U+1F17x │░🅰🅱🅲🅳🅴🅵🅶🅷🅸🅹🅺🅻🅼🅽🅾🅿🆀🆁🆂🆃🆄🆅🆆🆇🆈🆉░▒▒▒▍
# ░░▒▒▎Math. bold       │𝐀 𝐁 𝐂 𝐃 𝐄 𝐅 𝐆 𝐇 𝐈 𝐉 𝐊 𝐋 𝐌 𝐍 𝐎 𝐏 𝐐 𝐑 𝐒 𝐓 𝐔 𝐕 𝐖 𝐗 𝐘 𝐙 𝐚 𝐛 𝐜 𝐝 𝐞 𝐟 𝐠 𝐡 𝐢 𝐣 𝐤 𝐥 𝐦 𝐧 𝐨 𝐩 𝐪 𝐫 𝐬 𝐭 𝐮 𝐯 𝐰 𝐱 𝐲 𝐳░▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▍
# ░░▒▒▎Math. italic     │𝐴 𝐵 𝐶 𝐷 𝐸 𝐹 𝐺 𝐻 𝐼 𝐽 𝐾 𝐿 𝑀 𝑁 𝑂 𝑃 𝑄 𝑅 𝑆 𝑇 𝑈 𝑉 𝑊 𝑋 𝑌 𝑍 𝑎 𝑏 𝑐 𝑑 𝑒 𝑓 𝑔 ░ 𝑖 𝑗 𝑘 𝑙 𝑚 𝑛 𝑜 𝑝 𝑞 𝑟 𝑠 𝑡 𝑢 𝑣 𝑤 𝑥 𝑦 𝑧░▒▒▍
# ░░▒▒▎M. bold italic   │𝑨 𝑩 𝑪 𝑫 𝑬 𝑭 𝑮 𝑯 𝑰 𝑱 𝑲 𝑳 𝑴 𝑵 𝑶 𝑷 𝑸 𝑹 𝑺 𝑻 𝑼 𝑽 𝑾 𝑿 𝒀 𝒁 𝒂 𝒃 𝒄 𝒅 𝒆 𝒇 𝒈 𝒉 𝒊 𝒋 𝒌 𝒍 𝒎 𝒏 𝒐 𝒑 𝒒 𝒓 𝒔 𝒕 𝒖 𝒗 𝒘 𝒙 𝒚 𝒛░▒▒▍░▒▒▎                          │         │░░░░░░░░░░░░░░░░░░░░░░▒▒▒▒▒▒▍░░│
# ░░▒▒▎M. script        │𝒜   ░ 𝒞 𝒟   ░ 𝒢 ░ 𝒥 𝒦   ░ 𝒩 𝒪 𝒫 𝒬 ░ 𝒮 𝒯 𝒰 𝒱 𝒲 𝒳 𝒴 𝒵 𝒶 𝒷 𝒸 𝒹 ░ 𝒻 ░ 𝒽 𝒾 𝒿 𝓀 𝓁 𝓂 𝓃 ░ 𝓅 𝓆 𝓇 𝓈 𝓉 𝓊 𝓋 𝓌 𝓍 𝓎 𝓏░▒▒▍░▒▒̵▎̵░̵░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░⃘▒▒▒▒▒▒▍░░│
# ░░▒▒▎M. bold script   │𝓐 𝓑 𝓒 𝓓 𝓔 𝓕 𝓖 𝓗 𝓘 𝓙 𝓚 𝓛 𝓜 𝓝 𝓞 𝓟 𝓠 𝓡 𝓢 𝓣 𝓤 𝓥 𝓦 𝓧 𝓨 𝓩 𝓪 𝓫 𝓬 𝓭 𝓮 𝓯 𝓰 𝓱 𝓲 𝓳 𝓴 𝓵 𝓶 𝓷 𝓸 𝓹 𝓺 𝓻 𝓼 𝓽 𝓾 𝓿 𝔀 𝔁 𝔂 𝔃░▒▒▍░▒▒▎░░░#MATHEMATICAL ALPHANUMERICS# ░░░░░░░░░░░░░░░░░░░░░░░░░░░▒▒▒▒▒▒▍░░│
# ░░▒▒▎M. double-struck │𝔸 𝔹 ░ 𝔻 𝔼 𝔽 𝔾 ░ 𝕀 𝕁 𝕂 𝕃 𝕄 ░ 𝕆 𝕇 ░ ░ 𝕊 𝕋 𝕌 𝕍 𝕎 𝕏 𝕐 ░ 𝕒 𝕓 𝕔 𝕕 𝕖 𝕗 𝕘 𝕙 𝕚 𝕛 𝕜 𝕝 𝕞 𝕟 𝕠 𝕡 𝕢 𝕣 𝕤 𝕥 𝕦 𝕧 𝕨 𝕩 𝕪 𝕫░▒▒▍░▒▒▎Bold digits               │ U+1D7Cx │𝟎░𝟏░𝟐░𝟑░𝟒░𝟓░𝟔░𝟕░𝟖░𝟗░░░▒▒▒▒▒▒▍░░│
# ░░▒▒▎M. bold fraktur  │𝕬 𝕭 𝕮 𝕯 𝕰 𝕱 𝕲 𝕳 𝕴 𝕵 𝕶 𝕷 𝕸 𝕹 𝕺 𝕻 𝕼 𝕽 𝕾 𝕿 𝖀 𝖁 𝖂 𝖃 𝖄 𝖅 𝖆 𝖇 𝖈 𝖉 𝖊 𝖋 𝖌 𝖍 𝖎 𝖏 𝖐 𝖑 𝖒 𝖓 𝖔 𝖕 𝖖 𝖗 𝖘 𝖙 𝖚 𝖛 𝖜 𝖝 𝖞 𝖟░▒▒▍░▒▒▎Double-struck digits      │ U+1D7Dx │𝟘░𝟙░𝟚░𝟛░𝟜░𝟝░𝟞░𝟟░𝟠░𝟡░░░▒▒▒▒▒▒▍░░│
# ░░▒▒▎M. sans-serif    │𝖠 𝖡 𝖢 𝖣 𝖤 𝖥 𝖦 𝖧 𝖨 𝖩 𝖪 𝖫 𝖬 𝖭 𝖮 𝖯 𝖰 𝖱 𝖲 𝖳 𝖴 𝖵 𝖶 𝖷 𝖸 𝖹 𝖺 𝖻 𝖼 𝖽 𝖾 𝖿 𝗀 𝗁 𝗂 𝗃 𝗄 𝗅 𝗆 𝗇 𝗈 𝗉 𝗊 𝗋 𝗌 𝗍 𝗎 𝗏 𝗐 𝗑 𝗒 𝗓░▒▒▍░▒▒▎Sans-serif digits         │ U+1D7Ex │𝟢░𝟣░𝟤░𝟥░𝟦░𝟧░𝟨░𝟩░𝟪░𝟫░░░▒▒▒▒▒▒▍░░│
# ░░▒▒▎M. s.s. bold     │𝗔 𝗕 𝗖 𝗗 𝗘 𝗙 𝗚 𝗛 𝗜 𝗝 𝗞 𝗟 𝗠 𝗡 𝗢 𝗣 𝗤 𝗥 𝗦 𝗧 𝗨 𝗩 𝗪 𝗫 𝗬 𝗭 𝗮 𝗯 𝗰 𝗱 𝗲 𝗳 𝗴 𝗵 𝗶 𝗷 𝗸 𝗹 𝗺 𝗻 𝗼 𝗽 𝗾 𝗿 𝘀 𝘁 𝘂 𝘃 𝘄 𝘅 𝘆 𝘇░▒▒▍░▒▒▎Bold sans-serif digits    │ U+1D7Fx │𝟬░𝟭░𝟮░𝟯░𝟰░𝟱░𝟲░𝟳░𝟴░𝟵░░░▒▒▒▒▒▒▍░░│
# ░░▒▒▎M. s.s. italic   │𝘈 𝘉 𝘊 𝘋 𝘌 𝘍 𝘎 𝘏 𝘐 𝘑 𝘒 𝘓 𝘔 𝘕 𝘖 𝘗 𝘘 𝘙 𝘚 𝘛 𝘜 𝘝 𝘞 𝘟 𝘠 𝘡 𝘢 𝘣 𝘤 𝘥 𝘦 𝘧 𝘨 𝘩 𝘪 𝘫 𝘬 𝘭 𝘮 𝘯 𝘰 𝘱 𝘲 𝘳 𝘴 𝘵 𝘶 𝘷 𝘸 𝘹 𝘺 𝘻░▒▒▍░▒▒▎Monospace digits          │ U+1D7Fx │𝟶░𝟷░𝟸░𝟹░𝟺░𝟻░𝟼░𝟽░𝟾░𝟿░░░▒▒▒▒▒▒▍░░│
# ░░▒▒▎M. s.s. bold it. │𝘼 𝘽 𝘾 𝘿 𝙀 𝙁 𝙂 𝙃 𝙄 𝙅 𝙆 𝙇 𝙈 𝙉 𝙊 𝙋 𝙌 𝙍 𝙎 𝙏 𝙐 𝙑 𝙒 𝙓 𝙔 𝙕 𝙖 𝙗 𝙘 𝙙 𝙚 𝙛 𝙜 𝙝 𝙞 𝙟 𝙠 𝙡 𝙢 𝙣 𝙤 𝙥 𝙦 𝙧 𝙨 𝙩 𝙪 𝙫 𝙬 𝙭 𝙮 𝙯░▒▒▍░▒▒̵▎̵░̵░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░⃘▒▒▒▒▒▒▍░░│
# ░░▒▒▎M. monospace     │𝙰 𝙱 𝙲 𝙳 𝙴 𝙵 𝙶 𝙷 𝙸 𝙹 𝙺 𝙻 𝙼 𝙽 𝙾 𝙿 𝚀 𝚁 𝚂 𝚃 𝚄 𝚅 𝚆 𝚇 𝚈 𝚉 𝚊 𝚋 𝚌 𝚍 𝚎 𝚏 𝚐 𝚑 𝚒 𝚓 𝚔 𝚕 𝚖 𝚗 𝚘 𝚙 𝚚 𝚛 𝚜 𝚝 𝚞 𝚟 𝚠 𝚡 𝚢 𝚣░▒▒▍░▒▒▎░░░░░░░░░░░░░░░░░░░░#FULLWIDTH FORMS# ░░░░░░░░░░░░░░░░░░░░░▒▒▒▒▒▒▍░░│
# ̵̲░░⃘̥▒▒▎                 │̵̲░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░⃘̥▒▒▍░▒▒▎Digits full stop          │  U+248x │░░⒈░⒉░⒊░⒋░⒌░⒍░⒎░⒏░⒐░⒑░▒▒▒▒▒▒▍░░│
# ░░▒▒▎Fullwidth        ＡＢＣＤＥＦＧＨＩＪＫＬＭＮＯＰＱＲＳＴＵＶＷＸＹＺａｂｃｄｅｆｇｈｉｊｋｌｍｎｏｐｑｒｓｔｕｖｗｘｙｚ░▒▒▍░▒▒▎Fullwidth digits          │  U+FF1x │０１２３４５６７８９░░▒▒▒▒▒▒▍░░│
# ░░▒▒▲▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒△▒▒▍░▒▒▲▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒▒△▒▒▒▒▒▒▍░░│
# ░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░[mar²⁴]│
# (?m)^-+
#
# (?#hlinebot  ̲ )̲			[4;58;5;4m
#  (?#hlinemid  ̵ )̵ 		[9;34m
#  (?#hlinetop  ̄ )̄			[53;34m
#  (?#ringbot   ̥ )̥			[24m
#  (?#ringovr   ⃘ )⃘			[29m
#  (?#ringtop   ̊ )̊			[55m
#
#  ▴							[53;34m░
#  ▲							[53;94m▒
#  ▵							[53;34m░[55m
#  △							[53;94m▒[55m
#  «							[24;94;55m▍[34m
#  ▼							[34;4;58;5;4m▎[39m
#  ▾							[34;4;58;5;4m [39m
#  ▽							[94;24m▒
#  ▿							[94;24m░
#
#  ⥀(.+?[⇊⇈⬱⇇⇉⇶])				[34;2m\1 [m
#     ([⇊⇈⬱⇇⇉⇶].+?)⥀				[34;2m \1[m
# \x1d
# (\[\w{3}(\d\d|².)\])		[34m\1[m
#     (?<=▒)( \w{1,2} )(?=▒)		[1;44;38;5;15m\1[;94m
# ( )([*»])( )				[34;104;2;7;1m \2 [m
# #(.+?)#						[94;1m \1 [m
#     ([▒░│┌▎ ])~(.+?)~([▒░│─ ])	\1[49;94;1m▎\2 [22;94m\3
# ((?<=\n|\t)▍)(.+│)			\1[1;44;38;5;16m\2[m
#     (▎)(?=[\n \w░🅪⏨])			[34m\1[m
#     (▒)(-{4})(▒+▍)?				[94m\1[53m▒▒▒▒[55m\3[m
#     (▒)(-{3})(▒+▍)?				[94m\1[53m▒▒▒[55m\3[m
#                                                             ((?<=\n|\t)▍.*▍?)			[94m\1[m
#     ([│└┌─┐┘]+)					[34m\1[39m
#     (   ←.+)					[2;34m\1[m
#     (░)( [^░]{1,2} )			[34m░[24m\2[m
#     (░+▍?)		  				[34m\1[39m
#     (▒+▍?)						[94m\1[39m
#     (?i:(\bU\+)([0-9a-f]{1,5})(x)?([…,]?\s*)?([0-9a-f]{1,5})?(x)?)	[1;94m\1[22;34m\2[2m\3\4[34;22m\5[2m\6[22m
# \[(ⁱ)\]                     [91;1m \1 [39;22m
